@@ -446,9 +446,12 @@ QString UKUiThemeData::findTheme(const QString &themeName)
 
     if (!paths.contains(fallback))
         paths << fallback;
-
-    for(const QString &path : qAsConst(paths))
-    {
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+    for(int i=0;i<paths.size();i++){
+        const QString &path=paths[i];
+#else
+    for(const QString &path : qAsConst(paths)){
+#endif
         QDir dir(QString::fromLatin1("%1/ukui/themes/%2").arg(path, themeName));
         if (dir.isReadable())
             return dir.absolutePath();
@@ -609,8 +612,12 @@ QList<UKUiTheme> UKUiTheme::allThemes()
     paths << XdgDirs::dataHome(false);
     paths << XdgDirs::dataDirs();
 
-    for(const QString &path : qAsConst(paths))
-    {
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+    for(int i=0;i<paths.size();i++){
+        const QString &path=paths[i];
+#else
+    for(const QString &path : qAsConst(paths)){
+#endif
         QDir dir(QString::fromLatin1("%1/ukui/themes").arg(path));
         const QFileInfoList dirs = dir.entryInfoList(QDir::AllDirs | QDir::NoDotAndDotDot);
 
@@ -688,6 +695,8 @@ GlobalSettings::GlobalSettings():
     Settings(QL1S("ukui")),
     d_ptr(new GlobalSettingsPrivate(this))
 {
+/*ukui-control-center change the theme rather than panel*/
+/*
     if (value(QL1S("icon_theme")).toString().isEmpty())
     {
         qWarning() << QString::fromLatin1("Icon Theme not set. Fallbacking to Oxygen, if installed");
@@ -706,6 +715,7 @@ GlobalSettings::GlobalSettings():
     }
 
     fileChanged();
+*/
 }
 
 GlobalSettings::~GlobalSettings()
@@ -719,6 +729,8 @@ GlobalSettings::~GlobalSettings()
  ************************************************/
 void GlobalSettings::fileChanged()
 {
+/*ukcc change the theme rather than panel*/
+	/*
     Q_D(GlobalSettings);
     sync();
 
@@ -739,5 +751,6 @@ void GlobalSettings::fileChanged()
 
     emit settingsChangedFromExternal();
     emit settingsChanged();
+    */
 }
 
