@@ -1,19 +1,20 @@
 /*
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2.1, or (at your option)
- * any later version.
+ * This program or library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
- *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #include "customstyle.h"
@@ -22,7 +23,8 @@
 #include <QPainter>
 #include <QApplication>
 
-#if QT_CONFIG(toolbutton)
+//#if QT_CONFIG(toolbutton)
+/*以下代码是为了处理toolbutton 的箭头*/
 static void drawArrow(const QStyle *style, const QStyleOptionToolButton *toolbutton,
                       const QRect &rect, QPainter *painter, const QWidget *widget = 0)
 {
@@ -47,16 +49,18 @@ static void drawArrow(const QStyle *style, const QStyleOptionToolButton *toolbut
     arrowOpt.rect = rect;
     style->drawPrimitive(pe, &arrowOpt, painter, widget);
 }
-#endif // QT_CONFIG(toolbutton)
+//#endif // QT_CONFIG(toolbutton)
 
-CustomStyle::CustomStyle(const QString &proxyStyleName, QObject *parent) : QProxyStyle (proxyStyleName)
+CustomStyle::CustomStyle(const QString &proxyStyleName, bool multileWins, QObject *parent) : QProxyStyle (proxyStyleName)
 {
-
+    pluginName=proxyStyleName;
+    multileWindow=multileWins;
 }
 CustomStyle::~CustomStyle()
 {
 };
 
+/*Draws the given control using the provided painter with the style options specified by option.*/
 void CustomStyle::drawComplexControl(QStyle::ComplexControl cc, const QStyleOptionComplex *opt, QPainter *p, const QWidget *widget) const
 {
 
@@ -137,6 +141,7 @@ void CustomStyle::drawComplexControl(QStyle::ComplexControl cc, const QStyleOpti
 
 }
 
+/*下面对于CE_ToolButtonLabel　的处理是因为quicklaunch 插件出现了箭头*/
 void CustomStyle::drawControl(QStyle::ControlElement element, const QStyleOption *opt, QPainter *p, const QWidget *widget) const
 {
     switch (element) {
@@ -246,31 +251,111 @@ void CustomStyle::drawItemText(QPainter *painter, const QRect &rectangle, int al
 void CustomStyle::drawPrimitive(QStyle::PrimitiveElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
 {
     switch (element) {
-    //绘制 ToolButton
+    /*绘制 ToolButton
+     * 任务栏的不同插件需要的样式存在差异
+     * 在同一个PE中有两个toolbutton 的样式
+    */
     case PE_PanelButtonTool:{
-        painter->save();
-        painter->setRenderHint(QPainter::Antialiasing,true);
-        painter->setPen(Qt::NoPen);
-//        painter->setBrush(QColor(0xff,0xff,0xff,0xff));
-        painter->drawRoundedRect(option->rect,6,6);
-        if (option->state & State_MouseOver) {
-           if (option->state & State_Sunken) {
-               painter->setRenderHint(QPainter::Antialiasing,true);
-               painter->setPen(Qt::NoPen);
-               painter->setBrush(QColor(0xff,0xff,0xff,0x0f));
-               painter->drawRoundedRect(option->rect,6,6);
-           } else {
-               painter->setRenderHint(QPainter::Antialiasing,true);
-               painter->setPen(Qt::NoPen);
-               painter->setBrush(QColor(0xff,0xff,0xff,0x1f));
-               painter->drawRoundedRect(option->rect.adjusted(2,2,-2,-2),6,6);
-           }
+        if(QString::compare(pluginName,"taskbutton")==0)
+        {
+            painter->save();
+            painter->setRenderHint(QPainter::Antialiasing,true);
+            painter->setPen(Qt::NoPen);
+	    painter->setBrush(QColor(0xff,0xff,0xff,0x14));
+            if (option->state & State_Sunken) {
+                painter->setBrush(QColor(0xff,0xff,0xff,0x0f));
+            } else if (option->state & State_MouseOver) {
+                painter->setBrush(QColor(0xff,0xff,0xff,0x1f));
+            } else if (option->state & State_On) {
+                painter->setBrush(QColor(0xff,0xff,0xff,0x33));
+            }
+            painter->drawRoundedRect(option->rect.adjusted(2,2,-2,-2),6,6);
+            painter->restore();
+
+            if(multileWindow)
+            {
+                painter->save();
+                painter->setRenderHint(QPainter::Antialiasing, true);
+                painter->setPen(Qt::NoPen);
+                painter->setBrush(option->palette.color(QPalette::Highlight));
+                painter->drawEllipse(option->rect.topLeft() + QPointF(8.5, 4.5), 2.5, 2.5);
+                painter->setBrush(option->palette.color(QPalette::Highlight).light(125));
+                painter->drawEllipse(option->rect.topLeft() + QPointF(4.5, 4.5), 2.5, 2.5);
+                painter->restore();
+            }
+            return;
         }
-    painter->restore();
-    return;
+
+        else if(QString::compare(pluginName,"closebutton")==0)
+        {
+            painter->save();
+            painter->setRenderHint(QPainter::Antialiasing,true);
+            painter->setPen(Qt::NoPen);
+            //        painter->setBrush(QColor(0xff,0xff,0xff,0xff));
+            painter->drawRoundedRect(option->rect,6,6);
+            if (option->state & State_MouseOver) {
+                if (option->state & State_Sunken) {
+                    painter->setRenderHint(QPainter::Antialiasing,true);
+                    painter->setPen(Qt::NoPen);
+                    painter->setBrush(QColor(0xd7,0x34,0x35));
+                    painter->drawRoundedRect(option->rect,6,6);
+                } else {
+                    painter->setRenderHint(QPainter::Antialiasing,true);
+                    painter->setPen(Qt::NoPen);
+                    painter->setBrush(QColor(0xf0,0x41,0x34));
+                    painter->drawRoundedRect(option->rect,4,4);
+                }
+            }
+            painter->restore();
+            return;
+        }
+
+        else
+        {
+            painter->save();
+            painter->setRenderHint(QPainter::Antialiasing,true);
+            painter->setPen(Qt::NoPen);
+            painter->drawRoundedRect(option->rect,6,6);
+            if (option->state & State_MouseOver) {
+                if (option->state & State_Sunken) {
+                    painter->setRenderHint(QPainter::Antialiasing,true);
+                    painter->setPen(Qt::NoPen);
+                    painter->setBrush(QColor(0xff,0xff,0xff,0x0f));
+                    painter->drawRoundedRect(option->rect,6,6);
+                } else {
+                    painter->setRenderHint(QPainter::Antialiasing,true);
+                    painter->setPen(Qt::NoPen);
+                    painter->setBrush(QColor(0xff,0xff,0xff,0x1f));
+                    painter->drawRoundedRect(option->rect.adjusted(2,2,-2,-2),6,6);
+                }
+            }
+            painter->restore();
+            return;
+        }
+    }
+
+
+    case PE_PanelButtonCommand:{
+        painter->save();
+        painter->setRenderHint(QPainter::TextAntialiasing,true);
+        painter->setPen(Qt::NoPen);
+        painter->setBrush(Qt::blue);
+        if (option->state & State_MouseOver) {
+            if (option->state & State_Sunken) {
+                painter->setRenderHint(QPainter::Antialiasing,true);
+                painter->setPen(Qt::NoPen);
+                painter->setBrush(QColor(0xff,0x00,0x00));
+                painter->drawRoundedRect(option->rect,6,6);
+            } else {
+                painter->setRenderHint(QPainter::Antialiasing,true);
+                painter->setPen(Qt::NoPen);
+                painter->setBrush(QColor(0x00,0xff,0x00));
+                painter->drawRoundedRect(option->rect.adjusted(2,2,-2,-2),6,6);
+            }
+        }
+        painter->restore();
+        return;
     }break;
-
-
     }
     return QProxyStyle::drawPrimitive(element, option, painter, widget);
 
@@ -309,7 +394,7 @@ int CustomStyle::pixelMetric(QStyle::PixelMetric metric, const QStyleOption *opt
     return QProxyStyle::pixelMetric(metric, option, widget);
 }
 
-//
+/*使悬浮点击等样式生效*/
 void CustomStyle::polish(QWidget *widget)
 {
     widget->setAttribute(Qt::WA_Hover);
