@@ -31,16 +31,51 @@
 #include <fcntl.h>
 #include <syslog.h>
 #include <QStandardPaths>
+#include <QDateTime>
+#include <QMutex>
+#include <QFile>
+#include <QDir>
 /*! The ukui-panel is the panel of UKUI.
   Usage: ukui-panel [CONFIG_ID]
     CONFIG_ID      Section name in config file ~/.config/ukui/panel.conf
                    (default main)
  */
+void outputMessage(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+
+    QString txt;
+          switch (type) {
+          //调试信息提示
+          case QtDebugMsg:
+                  txt = QString("Debug: %1").arg(msg);
+                  break;
+
+          //一般的warning提示
+          case QtWarningMsg:
+                  txt = QString("Warning: %1").arg(msg);
+          break;
+          //严重错误提示
+          case QtCriticalMsg:
+                  txt = QString("Critical: %1").arg(msg);
+          break;
+          //致命错误提示
+          case QtFatalMsg:
+                  txt = QString("Fatal: %1").arg(msg);
+                  abort();
+          }
+    QFile outFile(qgetenv("HOME") +"/.config/ukui/ukui-panel.log");
+    outFile.open(QIODevice::WriteOnly | QIODevice::Append);
+    QTextStream ts(&outFile);  //
+    ts << txt << endl;
+}
 
 int main(int argc, char *argv[])
 {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,6,0))
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     UKUIPanelApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
     //Singleton
     QStringList homePath = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
@@ -62,7 +97,14 @@ int main(int argc, char *argv[])
         else
             qDebug() << "Load translations file" << locale << "failed!";
     }
-
+    if (locale == "tr_TR"){
+        if (translator.load("ukui-panel_tr.qm", "/usr/share/ukui-panel/panel/resources/"))
+            app.installTranslator(&translator);
+        else
+            qDebug() << "Load translations file" << locale << "failed!";
+    }
+    //注册MessageHandler
+    //qInstallMessageHandler(outputMessage);
 
     return app.exec();
 }
