@@ -48,6 +48,7 @@
 #include <QDropEvent>
 #include <XdgIcon>
 #include <XdgDirs>
+#include <QPainter>
 
 #include <KWindowSystem/KWindowSystem>
 #include <KWindowSystem/NETWM>
@@ -71,7 +72,6 @@
 #define CFG_KEY_ALIGNMENT          "alignment"
 #define CFG_KEY_FONTCOLOR          "font-color"
 #define CFG_KEY_BACKGROUNDCOLOR    "background-color"
-#define CFG_KEY_BACKGROUNDIMAGE    "background-image"
 #define CFG_KEY_OPACITY            "opacity"
 #define CFG_KEY_RESERVESPACE       "reserve-space"
 #define CFG_KEY_PLUGINS            "plugins"
@@ -91,10 +91,15 @@
 #define ICON_SIZE_MEDIUM  48
 #define ICON_SIZE_SMALL   32
 
-#define PANEL_SETTINGS "org.ukui.panel.settings"
-#define PANEL_SIZE_KEY "panelsize"
-#define ICON_SIZE_KEY "iconsize"
-#define PANEL_POSITION_KEY "panelposition"
+#define PANEL_SETTINGS      "org.ukui.panel.settings"
+#define PANEL_SIZE_KEY      "panelsize"
+#define ICON_SIZE_KEY       "iconsize"
+#define PANEL_POSITION_KEY  "panelposition"
+#define SHOW_TASKVIEW       "showtaskview"
+#define SHOW_NIGHTMODE      "shownightmode"
+
+#define TRANSPARENCY_SETTINGS       "org.ukui.control-center.personalise"
+#define TRANSPARENCY_KEY            "transparency"
 
 /************************************************
  Returns the Position by the string.
@@ -113,7 +118,7 @@ IUKUIPanel::Position UKUIPanel::strToPosition(const QString& str, IUKUIPanel::Po
 
 /************************************************
  Return  string representation of the position
- ************************************************/
+ *******************************************connect(QApplication::desktop(), &QDesktopWidget::resized, this, &UKUIPanel::ensureVisible);*****/
 QString UKUIPanel::positionToStr(IUKUIPanel::Position position)
 {
     switch (position)
@@ -175,6 +180,10 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
     // To workaround this regression bug, we need to add this window flag here.
     // However, since the panel gets no keyboard focus, this may decrease accessibility since
     // it's not possible to use the panel with keyboards. We need to find a better solution later.
+
+    /*部分组建在点击任务栏空白位置的时候，无法收回窗口，想要正常收回窗口，需要取消下面的窗口属性或者其他应用监听点击taskbar的点击信号
+     * 不使用此窗口属性则需要在开始菜单，任务视图，快速启动栏三个界面组件中设置　setFocusPolicy(Qt::NoFocus);
+     */
     flags |= Qt::WindowDoesNotAcceptFocus;
 
     setWindowFlags(flags);
@@ -190,6 +199,7 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
     setWindowTitle("UKUI Panel");
     setObjectName(QString("UKUIPanel %1").arg(configGroup));
 
+
     //UKUIPanel (inherits QFrame) -> lav (QGridLayout) -> UKUIPanelWidget (QFrame) -> UKUIPanelLayout
     UKUIPanelWidget = new QFrame(this);
     UKUIPanelWidget->setObjectName("BackgroundWidget");
@@ -215,12 +225,15 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
     mShowDelayTimer.setInterval(PANEL_SHOW_DELAY);
     connect(&mShowDelayTimer, &QTimer::timeout, [this] { showPanel(mAnimationTime > 0); });
 
+    /* 监听屏幕分辨路改变resized　和屏幕数量改变screenCountChanged
+     * 或许存在无法监听到分辨率改变的情况（qt5.6），若出现则可换成
+     * connect(QApplication::primaryScreen(),&QScreen::geometryChanged, this,&UKUIPanel::ensureVisible);
+　　　*/
     connect(QApplication::desktop(), &QDesktopWidget::resized, this, &UKUIPanel::ensureVisible);
     connect(QApplication::desktop(), &QDesktopWidget::screenCountChanged, this, &UKUIPanel::ensureVisible);
 
     // connecting to QDesktopWidget::workAreaResized shouldn't be necessary,
     // as we've already connceted to QDesktopWidget::resized, but it actually
-    // is. Read mode on https://github.com/ukui/ukui-panel/pull/310
     connect(QApplication::desktop(), &QDesktopWidget::workAreaResized,
             this, &UKUIPanel::ensureVisible);
 
@@ -237,7 +250,6 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
     loadPlugins();
 
     show();
-
     // show it the first time, despite setting
     if (mHidable)
     {
@@ -246,8 +258,27 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
     }
     UKUIPanelApplication *a = reinterpret_cast<UKUIPanelApplication*>(qApp);
     connect(a, &UKUIPanelApplication::primaryScreenChanged, this, &UKUIPanel::setPanelGeometry);
+
     const QByteArray id(PANEL_SETTINGS);
     gsettings = new QGSettings(id);
+
+    
+    const QByteArray transparency_id(TRANSPARENCY_SETTINGS);
+    if(QGSettings::isSchemaInstalled(transparency_id)){
+        transparency_gsettings = new QGSettings(transparency_id);
+        setPanelBackground(true);
+        }
+    connect(transparency_gsettings, &QGSettings::changed, this, [=] (const QString &key){
+        if(key==TRANSPARENCY_KEY)
+            setPanelBackground(true);
+    });
+//updateStyleSheet();
+
+
+    setPanelsize(PANEL_SIZE_MEDIUM);
+    setIconsize(ICON_SIZE_MEDIUM);
+    setPanelsize(PANEL_SIZE_SMALL);
+    setIconsize(ICON_SIZE_SMALL);
 }
 
 /************************************************
@@ -294,10 +325,6 @@ void UKUIPanel::readSettings()
     if (color.isValid())
         setBackgroundColor(color, true);
 
-    QString image = mSettings->value(CFG_KEY_BACKGROUNDIMAGE, "").toString();
-    if (!image.isEmpty())
-        setBackgroundImage(image, false);
-
     mLockPanel = mSettings->value(CFG_KEY_LOCKPANEL, false).toBool();
 
     mSettings->endGroup();
@@ -335,7 +362,6 @@ void UKUIPanel::saveSettings(bool later)
 
     mSettings->setValue(CFG_KEY_FONTCOLOR, mFontColor.isValid() ? mFontColor : QColor());
     mSettings->setValue(CFG_KEY_BACKGROUNDCOLOR, mBackgroundColor.isValid() ? mBackgroundColor : QColor());
-    mSettings->setValue(CFG_KEY_BACKGROUNDIMAGE, QFileInfo(mBackgroundImage).exists() ? mBackgroundImage : QString());
     mSettings->setValue(CFG_KEY_OPACITY, mOpacity);
     mSettings->setValue(CFG_KEY_RESERVESPACE, mReserveSpace);
 
@@ -350,9 +376,7 @@ void UKUIPanel::saveSettings(bool later)
 }
 
 
-/************************************************
-
- ************************************************/
+/*确保任务栏在调整分辨率和增加·屏幕之后能保持显示正常*/
 void UKUIPanel::ensureVisible()
 {
     if (!canPlacedOn(mScreenNum, mPosition))
@@ -595,23 +619,17 @@ void UKUIPanel::setMargins()
     }
 }
 
+/*
+ *　ukui-panel　的实时调整功能
+ *　QEvent::LayoutRequest　能监听到widget should be relayouted时候的信号
+ *　emit realigned()　信号在PanelPluginsModel类中传给插件的realign函数
+ * 所有的插件类都需要重写这个函数用以跟任务栏的位置保持一致
+ * UKUIPanel::event -> UKUIPanel::realign() -> Plugin::realign() ->UKUITrayPlugin:realign
+*/
 void UKUIPanel::realign()
 {
-    QStringList sheet;
-//    QGSettings *gsettings;
-//    gsettings= new QGSettings("org.mate.interface", "", this);
-//    QString mode;
-//    mode=gsettings->get("gtk-theme").toString();
-//    qDebug()<<"ukui-theme:"<<mode;
-//    if(mode=="ukui-blue")
-//    {
-//        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
-//    }
-//    else
-//    {
-        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,90%); }");
-//    }
-    setStyleSheet(sheet.join("\n"));
+    //updateStyleSheet();
+    emit realigned();
     if (!isVisible())
         return;
 #if 0
@@ -658,7 +676,7 @@ void UKUIPanel::updateWmStrut()
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  rect.top() + getReserveDimension(), rect.left(), rect.right(),
                                             /* Bottom */  0, 0, 0
-                                           );
+                                            );
             break;
 
         case UKUIPanel::PositionBottom:
@@ -667,7 +685,7 @@ void UKUIPanel::updateWmStrut()
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  0, 0, 0,
                                             /* Bottom */  wholeScreen.bottom() - rect.bottom() + getReserveDimension(), rect.left(), rect.right()
-                                           );
+                                            );
             break;
 
         case UKUIPanel::PositionLeft:
@@ -676,7 +694,7 @@ void UKUIPanel::updateWmStrut()
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  0, 0, 0,
                                             /* Bottom */  0, 0, 0
-                                           );
+                                            );
 
             break;
 
@@ -686,9 +704,9 @@ void UKUIPanel::updateWmStrut()
                                             /* Right  */  wholeScreen.right() - rect.right() + getReserveDimension(), rect.top(), rect.bottom(),
                                             /* Top    */  0, 0, 0,
                                             /* Bottom */  0, 0, 0
-                                           );
+                                            );
             break;
-    }
+        }
     } else
     {
         KWindowSystem::setExtendedStrut(wid,
@@ -696,7 +714,7 @@ void UKUIPanel::updateWmStrut()
                                         /* Right  */  0, 0, 0,
                                         /* Top    */  0, 0, 0,
                                         /* Bottom */  0, 0, 0
-                                       );
+                                        );
     }
 }
 
@@ -765,22 +783,22 @@ int UKUIPanel::findAvailableScreen(UKUIPanel::Position position)
  ************************************************/
 void UKUIPanel::showConfigDialog()
 {
-//    if (mConfigDialog.isNull())
-//        mConfigDialog = new ConfigPanelDialog(this, nullptr /*make it top level window*/);
+        if (mConfigDialog.isNull())
+            mConfigDialog = new ConfigPanelDialog(this, nullptr /*make it top level window*/);
 
-//    mConfigDialog->showConfigPanelPage();
-//    mStandaloneWindows->observeWindow(mConfigDialog.data());
-//    mConfigDialog->show();
-//    mConfigDialog->raise();
-//    mConfigDialog->activateWindow();
-//    WId wid = mConfigDialog->windowHandle()->winId();
-
-//    KWindowSystem::activateWindow(wid);
-//    KWindowSystem::setOnDesktop(wid, KWindowSystem::currentDesktop());
-
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
+        mConfigDialog->showConfigPanelPage();
+        mStandaloneWindows->observeWindow(mConfigDialog.data());
         mConfigDialog->show();
-        //mConfigWidget->positionChanged();
+        mConfigDialog->raise();
+        mConfigDialog->activateWindow();
+        WId wid = mConfigDialog->windowHandle()->winId();
+
+        KWindowSystem::activateWindow(wid);
+        KWindowSystem::setOnDesktop(wid, KWindowSystem::currentDesktop());
+
+    mConfigDialog = new ConfigPanelDialog(this, nullptr);
+    mConfigDialog->show();
+    //mConfigWidget->positionChanged();
 
 }
 
@@ -805,68 +823,156 @@ void UKUIPanel::showAddPluginDialog()
 }
 
 
-/************************************************
-
- ************************************************/
-
-void UKUIPanel::setPanelStyle()
+/*右键　设置任务栏选项*/
+void UKUIPanel::setUpPanel()
 {
-
+    if(QFileInfo::exists(QString("/usr/bin/ukui-control-center")))
+    {
+        QProcess *process =new QProcess(this);
+        process->startDetached("/usr/bin/ukui-control-center  -d");
+        process->deleteLater();
+    }
+    else
+        qDebug()<<"not find /usr/bin/ukui-control-center";
 }
 
+/*右键　系统监视器选项*/
 void UKUIPanel::systeMonitor()
 {
-//    system("mate-system-monitor");
-    if(QFileInfo::exists(QString("/usr/bin/mate-system-monitor")))
+    if(QFileInfo::exists(QString("/usr/bin/mate-system-monitor")) || QFileInfo::exists(QString("/usr/bin/ukui-system-monitor")))
     {
-    QProcess *process =new QProcess(this);
-    process->startDetached("/usr/bin/mate-system-monitor");
+        QProcess *process =new QProcess(this);
+        if(QFileInfo::exists(QString("/usr/bin/ukui-system-monitor")))
+            process->startDetached("/usr/bin/ukui-system-monitor");
+        else
+            process->startDetached("/usr/bin/mate-system-monitor");
     }
-    else{qDebug()<<"not find /usr/bin/mate-system-monitor"<<endl;}
+    else
+        qDebug()<<"not find /usr/bin/mate-system-monitor or /usr/bin/ukui-system-monitor";
 }
-#include <KWindowSystem/KWindowSystem>
-#include <KWindowSystem/NETWM>
+
+/*任务栏大小和方向的调整*/
+void UKUIPanel::adjustPanel()
+{
+    QAction *pmenuaction_s;
+    QAction *pmenuaction_m;
+    QAction *pmenuaction_l;
+
+    pmenuaction_s=new QAction(this);
+    pmenuaction_s->setText(tr("Small"));
+    pmenuaction_m=new QAction(this);
+    pmenuaction_m->setText(tr("Medium"));
+    pmenuaction_l=new QAction(this);
+    pmenuaction_l->setText(tr("Large"));
+
+
+    QMenu *pmenu_panelsize;
+    pmenu_panelsize=new QMenu(this);
+    pmenu_panelsize->setTitle(tr("Adjustment Size"));
+    pmenu_panelsize->addAction(pmenuaction_s);
+    pmenu_panelsize->addAction(pmenuaction_m);
+    pmenu_panelsize->addAction(pmenuaction_l);
+    pmenu_panelsize->setWindowOpacity(0.9);
+    menu->addMenu(pmenu_panelsize);
+
+    pmenuaction_s->setCheckable(true);
+    pmenuaction_m->setCheckable(true);
+    pmenuaction_l->setCheckable(true);
+    pmenuaction_s->setChecked(gsettings->get(PANEL_SIZE_KEY).toInt()==PANEL_SIZE_SMALL);
+    pmenuaction_m->setChecked(gsettings->get(PANEL_SIZE_KEY).toInt()==PANEL_SIZE_MEDIUM);
+    pmenuaction_l->setChecked(gsettings->get(PANEL_SIZE_KEY).toInt()==PANEL_SIZE_LARGE);
+
+    connect(pmenuaction_s,&QAction::triggered,[this] {
+        setPanelsize(PANEL_SIZE_SMALL);
+        setIconsize(ICON_SIZE_SMALL);
+    });
+    connect(pmenuaction_m,&QAction::triggered,[this] {
+        setPanelsize(PANEL_SIZE_MEDIUM);
+        setIconsize(ICON_SIZE_MEDIUM);
+    });
+    connect(pmenuaction_l,&QAction::triggered,[this] {
+        setPanelsize(PANEL_SIZE_LARGE);
+        setIconsize(ICON_SIZE_LARGE);
+    });
+    pmenu_panelsize->setDisabled(mLockPanel);
+
+    QAction *pmenuaction_top;
+    QAction *pmenuaction_bottom;
+    QAction *pmenuaction_left;
+    QAction *pmenuaction_right;
+    pmenuaction_top=new QAction(this);
+    pmenuaction_top->setText(tr("Up"));
+    pmenuaction_bottom=new QAction(this);
+    pmenuaction_bottom->setText(tr("Bottom"));
+    pmenuaction_left=new QAction(this);
+    pmenuaction_left->setText(tr("Left"));
+    pmenuaction_right=new QAction(this);
+    pmenuaction_right->setText(tr("Right"));
+    QMenu *pmenu_positon;
+    pmenu_positon=new QMenu(this);
+    pmenu_positon->setTitle(tr("Adjustment Position"));
+    pmenu_positon->addAction(pmenuaction_top);
+    pmenu_positon->addAction(pmenuaction_bottom);
+    pmenu_positon->addAction(pmenuaction_left);
+    pmenu_positon->addAction(pmenuaction_right);
+    menu->addMenu(pmenu_positon);
+
+    pmenuaction_top->setCheckable(true);
+    pmenuaction_bottom->setCheckable(true);
+    pmenuaction_left->setCheckable(true);
+    pmenuaction_right->setCheckable(true);
+    pmenuaction_top->setChecked(gsettings->get(PANEL_POSITION_KEY).toInt()==1);
+    pmenuaction_bottom->setChecked(gsettings->get(PANEL_POSITION_KEY).toInt()==0);
+    pmenuaction_left->setChecked(gsettings->get(PANEL_POSITION_KEY).toInt()==2);
+    pmenuaction_right->setChecked(gsettings->get(PANEL_POSITION_KEY).toInt()==3);
+
+
+    connect(pmenuaction_top,&QAction::triggered, [this] { setPanelPosition(PositionTop);});
+    connect(pmenuaction_bottom,&QAction::triggered, [this] { setPanelPosition(PositionBottom);});
+    connect(pmenuaction_left,&QAction::triggered, [this] { setPanelPosition(PositionLeft);});
+    connect(pmenuaction_right,&QAction::triggered, [this] { setPanelPosition(PositionRight);});
+    pmenu_positon->setWindowOpacity(0.9);
+    pmenu_positon->setDisabled(mLockPanel);
+
+}
+/*右键　显示桌面选项*/
 void UKUIPanel::showDesktop()
 {
     KWindowSystem::setShowingDesktop(!KWindowSystem::showingDesktop());
 }
+
+/*右键　显示任务视图　选项*/
 void UKUIPanel::showTaskView()
 {
-    system("ukui-window-switch --show-workspace");
+//    system("ukui-window-switch --show-workspace");
+    if(gsettings->keys().contains(SHOW_TASKVIEW))
+    {
+        if(gsettings->get(SHOW_TASKVIEW).toBool()){
+            gsettings->set(SHOW_TASKVIEW,false);
+        }
+        else
+            gsettings->set(SHOW_TASKVIEW,true);
+    }
+}
+
+/*右键　显示夜间模式按钮　选项*/
+void UKUIPanel::showNightModeButton()
+{
+//    system("ukui-window-switch --show-workspace");
+    if(gsettings->keys().contains(SHOW_NIGHTMODE))
+    {
+        if(gsettings->get(SHOW_NIGHTMODE).toBool()){
+            gsettings->set(SHOW_NIGHTMODE,false);
+        }
+        else
+            gsettings->set(SHOW_NIGHTMODE,true);
+    }
 }
 void UKUIPanel::updateStyleSheet()
 {
-
-//    sheet << QString("Plugin > QAbstractButton, UKUiTray { qproperty-iconSize: %1px %1px; }").arg(mIconSize);
-//    sheet << QString("Plugin > * > QAbstractButton, TrayIcon { qproperty-iconSize: %1px %1px; }").arg(mIconSize);
-
-//    if (mFontColor.isValid())
-//        sheet << QString("Plugin * { color: " + mFontColor.name() + "; }");
-
-//    QString object = UKUIPanelWidget->objectName();
-
-//    if (mBackgroundColor.isValid())
-//    {
-//        QString color = QString("%1, %2, %3, %4")
-//            .arg(mBackgroundColor.red())
-//            .arg(mBackgroundColor.green())
-//            .arg(mBackgroundColor.blue())
-//            .arg((float) mOpacity / 100);
-////        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(" + color + "); }");
-
-//    }
-//   sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(8,10,12,90%); }");
-//        GSettings *settings = NULL;
-//        QString str;
-//        char *path;
-//        char color_hex[10];
-//        path = g_strdup_printf ("%s/","/org/mate/desktop/interface");
-//        settings = g_settings_new_with_path ("org.mate.interface",path);
-//        if(!strcmp(g_settings_get_string(settings, "gtk-theme"),"ukui-white"))
-//        {
-//            qDebug()<<"ukui-white";
-//        }
-
+    QStringList sheet;
+    //sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,%1); }").arg(transparency_gsettings->get(TRANSPARENCY_KEY).toDouble());
+    setStyleSheet(sheet.join("\n"));
 }
 
 
@@ -891,12 +997,13 @@ void UKUIPanel::setPanelSize(int value, bool save)
 /************************************************
 
  ************************************************/
+
 void UKUIPanel::setIconSize(int value, bool save)
 {
     if (mIconSize != value)
     {
         mIconSize = value;
-        updateStyleSheet();
+        //updateStyleSheet();
         mLayout->setLineSize(mIconSize);
 
         if (save)
@@ -1012,7 +1119,7 @@ void UKUIPanel::setAlignment(Alignment value, bool save)
 void UKUIPanel::setFontColor(QColor color, bool save)
 {
     mFontColor = color;
-    updateStyleSheet();
+    //updateStyleSheet();
 
     if (save)
         saveSettings(true);
@@ -1024,22 +1131,23 @@ void UKUIPanel::setFontColor(QColor color, bool save)
 void UKUIPanel::setBackgroundColor(QColor color, bool save)
 {
     mBackgroundColor = color;
-    updateStyleSheet();
+    //updateStyleSheet();
 
     if (save)
         saveSettings(true);
 }
 
-/************************************************
-
- ************************************************/
-void UKUIPanel::setBackgroundImage(QString path, bool save)
+/*设置任务栏的背景色，可通过gsetting修改*/
+void UKUIPanel::setPanelBackground(bool effective)
 {
-    mBackgroundImage = path;
-    updateStyleSheet();
-
-    if (save)
-        saveSettings(true);
+    if(effective)
+    {
+        QStringList sheet;
+        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,%1); }").arg(transparency_gsettings->get(TRANSPARENCY_KEY).toDouble());
+        setStyleSheet(sheet.join("\n"));
+    }
+    //else
+        //updateStyleSheet();
 }
 
 
@@ -1049,7 +1157,7 @@ void UKUIPanel::setBackgroundImage(QString path, bool save)
 void UKUIPanel::setOpacity(int opacity, bool save)
 {
     mOpacity = opacity;
-    updateStyleSheet();
+    //updateStyleSheet();
 
     if (save)
         saveSettings(true);
@@ -1107,7 +1215,7 @@ bool UKUIPanel::event(QEvent *event)
         // Sometimes Qt needs to re-create the underlying window of the widget and
         // the winId() may be changed at runtime. So we need to reset all X11 properties
         // when this happens.
-        qDebug() << "WinIdChange" << hex << effectiveWinId() << "handle" << windowHandle() << windowHandle()->screen();
+        //qDebug() << "WinIdChange" << hex << effectiveWinId() << "handle" << windowHandle() << windowHandle()->screen();
 
         // Qt::WA_X11NetWmWindowTypeDock becomes ineffective in Qt 5
         // See QTBUG-39887: https://bugreports.qt-project.org/browse/QTBUG-39887
@@ -1149,18 +1257,44 @@ void UKUIPanel::showEvent(QShowEvent *event)
     realign();
 }
 
+/* 使用paintEvent 对panel进行绘制的时候有如下问题：
+ * 1.绘制速度需要鼠标事件触发，明显的切换不流畅
+ * 2.部分区域绘制不能生效，调整任务栏高度之后才能生效
+ */
+/*
+void UKUIPanel::paintEvent(QPaintEvent *)
+{
+    QStyleOption opt;
+    opt.init(this);
+    QPainter p(this);
+    p.setPen(Qt::NoPen);
+    QColor c;
+    c.setRed(19);
+    c.setGreen(22);
+    c.setBlue(28);
+    c.setAlphaF(transparency_gsettings->get(TRANSPARENCY_KEY).toDouble());
+    p.setBrush(QBrush(c));
 
-/************************************************
+    p.setRenderHint(QPainter::Antialiasing);
+    p.drawRoundedRect(opt.rect,20,20);
+    style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+}
+*/
 
- ************************************************/
+/*Right-Clicked Menu of ukui-panel
+ * it's a Popup Menu
+*/
 void UKUIPanel::showPopupMenu(Plugin *plugin)
 {
-    PopupMenu * menu = new PopupMenu(tr("Panel"), this);
+    menu = new PopupMenu(tr("Panel"), this);
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    menu->setIcon(XdgIcon::fromTheme("configure-toolbars"));
-
-    // Plugin Menu ..............................
+    /* @new features
+     * //Plugin Menu  负责显示插件的菜单项，ukui３.0的设计暂时不需要插件菜单项
+     * 关于后续的插件右键菜单的详细调整
+     * 如果需要在任务栏菜单项上面添加 插件的菜单选项就放开此功能
+     * 放开此功能可以丰富插件右键菜单，windows是这样做的
+     */
     if (plugin)
     {
         QMenu *m = plugin->popupMenu();
@@ -1179,9 +1313,7 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
         }
     }
 
-
-    // Panel menu ...............................
-/*
+    /*
     menu->addTitle(QIcon(), tr("Panel"));
     menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
                    tr("Configure Panel"),
@@ -1191,88 +1323,46 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
                    tr("Manage Widgets"),
                    this, SLOT(showAddPluginDialog())
                   )->setDisabled(mLockPanel);
-*/
-    /*
-    menu->setWindowOpacity(0.9);
-    menu->addAction(QIcon("/usr/share/ukui-panel/panel/img/setting.svg"),
-                   tr("Set up Panel"),
-                   this, SLOT(panelBackgroundChange())
-                  )->setDisabled(mLockPanel);
+    */
+
+    menu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("document-page-setup").pixmap(24,24).toImage()))),
+                    tr("Set up Panel"),
+                    this, SLOT(setUpPanel())
+                    )->setDisabled(mLockPanel);
 
     menu->addSeparator();
-*/
+
+    QAction * showtaskview = menu->addAction(tr("Show Taskview"));
+    showtaskview->setDisabled(mLockPanel);
+    showtaskview->setCheckable(true);
+    showtaskview->setChecked(gsettings->get(SHOW_TASKVIEW).toBool());
+    connect(showtaskview, &QAction::triggered, [this] { showTaskView(); });
+
+#if (QT_VERSION > QT_VERSION_CHECK(5,7,0))
+    QAction * shownightmode = menu->addAction(tr("Show Nightmode"));
+    shownightmode->setDisabled(mLockPanel);
+    shownightmode->setCheckable(true);
+    shownightmode->setChecked(gsettings->get(SHOW_NIGHTMODE).toBool());
+    connect(shownightmode, &QAction::triggered, [this] { showNightModeButton(); });
+#endif
+
     menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
-                   tr("Show Taskview"),
-                   this, SLOT(showTaskView())
-                  )->setDisabled(mLockPanel);
-
-        menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
-                       tr("Show Desktop"),
-                       this, SLOT(showDesktop())
-                      )->setDisabled(mLockPanel);
+                    tr("Show Desktop"),
+                    this, SLOT(showDesktop())
+                    );
 
     menu->addSeparator();
 
-    menu->addAction(XdgIcon::fromTheme(QLatin1String("list-remove")),               
-    tr("Show System Monitor"),
-                   this, SLOT(systeMonitor())
-                  )->setDisabled(mLockPanel);
+    menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
+                    tr("Show System Monitor"),
+                    this, SLOT(systeMonitor())
+                    );
 
     menu->addSeparator();
 
-    QAction *pmenuaction_s;
-    QAction *pmenuaction_m;
-    QAction *pmenuaction_l;
+    adjustPanel();
 
-    pmenuaction_s=new QAction(this);
-    pmenuaction_s->setText(tr("Small"));
-    pmenuaction_m=new QAction(this);
-    pmenuaction_m->setText(tr("Media"));
-    pmenuaction_l=new QAction(this);
-    pmenuaction_l->setText(tr("Large"));
-
-
-    QMenu *pmenu_panelsize;
-    pmenu_panelsize=new QMenu(this);
-    pmenu_panelsize->setTitle(tr("Adjustment Size"));
-    pmenu_panelsize->addAction(pmenuaction_s);
-    pmenu_panelsize->addAction(pmenuaction_m);
-    pmenu_panelsize->addAction(pmenuaction_l);
-    menu->addMenu(pmenu_panelsize);
-
-    connect(pmenuaction_s,SIGNAL(triggered()),this,SLOT(changeSizeToSmall()));
-    connect(pmenuaction_m,SIGNAL(triggered()),this,SLOT(changeSizeToMedium()));
-    connect(pmenuaction_l,SIGNAL(triggered()),this,SLOT(changeSizeToLarge()));
-    menu->addSeparator();
-
-    QAction *pmenuaction_top;
-    QAction *pmenuaction_bottom;
-    QAction *pmenuaction_left;
-    QAction *pmenuaction_right;
-    pmenuaction_top=new QAction(this);
-    pmenuaction_top->setText(tr("Up"));
-    pmenuaction_bottom=new QAction(this);
-    pmenuaction_bottom->setText(tr("Bottom"));
-    pmenuaction_left=new QAction(this);
-    pmenuaction_left->setText(tr("Left"));
-    pmenuaction_right=new QAction(this);
-    pmenuaction_right->setText(tr("Right"));
-    QMenu *pmenu_positon;
-    pmenu_positon=new QMenu(this);
-    pmenu_positon->setTitle(tr("Adjustment Position"));
-    pmenu_positon->addAction(pmenuaction_top);
-    pmenu_positon->addAction(pmenuaction_bottom);
-    pmenu_positon->addAction(pmenuaction_left);
-    pmenu_positon->addAction(pmenuaction_right);
-    menu->addMenu(pmenu_positon);
-
-    connect(pmenuaction_top,SIGNAL(triggered()),this,SLOT(changePositionToTop()));
-    connect(pmenuaction_bottom,SIGNAL(triggered()),this,SLOT(changePositionToBottom()));
-    connect(pmenuaction_left,SIGNAL(triggered()),this,SLOT(changePositionToLeft()));
-    connect(pmenuaction_right,SIGNAL(triggered()),this,SLOT(changePositionToRight()));
-    pmenu_positon->setDisabled(mLockPanel);
-
-/*
+    /*
     UKUIPanelApplication *a = reinterpret_cast<UKUIPanelApplication*>(qApp);
     menu->addAction(XdgIcon::fromTheme(QLatin1String("list-add")),
                    tr("Add New Panel"),
@@ -1294,12 +1384,26 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
     connect(act_lock, &QAction::triggered, [this] { mLockPanel = !mLockPanel; saveSettings(false); });
 
     //Hidden features, lock the panel
-/*
+    /*
     menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
                    tr("Reset Panel"),
                    this, SLOT(panelReset())
                   )->setDisabled(mLockPanel);
 */
+
+    if(QFileInfo::exists(QString("/usr/bin/ukui-about")))
+    {
+        QAction *about;
+        about=new QAction(this);
+        about->setText(tr("About Kylin"));
+        menu->addAction(about);
+        about->setDisabled(mLockPanel);
+        connect(about,&QAction::triggered, [this] {
+            QProcess *process =new QProcess(this);
+            process->startDetached("/usr/bin/ukui-about");
+        });
+
+    }
 #ifdef DEBUG
     menu->addSeparator();
     menu->addAction("Exit (debug only)", qApp, SLOT(quit()));
@@ -1448,9 +1552,9 @@ void UKUIPanel::pluginMoved(Plugin * plug)
 void UKUIPanel::userRequestForDeletion()
 {
     const QMessageBox::StandardButton ret
-        = QMessageBox::warning(this, tr("Remove Panel", "Dialog Title") ,
-            tr("Removing a panel can not be undone.\nDo you want to remove this panel?"),
-            QMessageBox::Yes | QMessageBox::No);
+            = QMessageBox::warning(this, tr("Remove Panel", "Dialog Title") ,
+                                   tr("Removing a panel can not be undone.\nDo you want to remove this panel?"),
+                                   QMessageBox::Yes | QMessageBox::No);
 
     if (ret != QMessageBox::Yes) {
         return;
@@ -1486,7 +1590,7 @@ void UKUIPanel::hidePanel()
 {
     if (mHidable && !mHidden
             && !mStandaloneWindows->isAnyWindowShown()
-       )
+            )
         mHideTimer.start();
 }
 
@@ -1586,33 +1690,54 @@ bool UKUIPanel::isPluginSingletonAndRunnig(QString const & pluginId) const
 
 void UKUIPanel::setPanelPosition(Position position)
 {
-    setPosition(0,position,true);
+    QDBusMessage message=QDBusMessage::createSignal("/panel/settings", "com.ukui.panel.settings", "SendPanelSetings");
+    if(position==PositionTop)
+    {
+        setPosition(0,PositionTop,true);
+        gsettings->set(PANEL_POSITION_KEY,1);
+        message<<1;
+        QDBusConnection::sessionBus().send(message);
+    }
+    else if(position==PositionLeft)
+    {
+        setPosition(0,PositionLeft,true);
+        gsettings->set(PANEL_POSITION_KEY,2);
+        message<<2;
+        QDBusConnection::sessionBus().send(message);
+    }
+    else if(position==PositionRight)
+    {
+        this->setPosition(0,PositionRight,true);
+        gsettings->set(PANEL_POSITION_KEY,3);
+        message<<3;
+        QDBusConnection::sessionBus().send(message);
+    }
+    else
+    {
+        setPosition(0,PositionBottom,true);
+        gsettings->set(PANEL_POSITION_KEY,0);
+        message<<0;
+        QDBusConnection::sessionBus().send(message);
+    }
 }
 
-void UKUIPanel::changePositionToTop()
+/*ukui-panel use gsettings to set panelsize & iconsize
+ * it need to emit signals to other application
+ * and for users to adjust through the command lines
+*/
+void UKUIPanel::setPanelsize(int panelsize)
 {
-    setPosition(0,PositionTop,true);
-    gsettings->set(PANEL_POSITION_KEY,1);
+    setPanelSize(panelsize,true);
+    gsettings->set(PANEL_SIZE_KEY,panelsize);
 }
 
-void UKUIPanel::changePositionToBottom()
+void UKUIPanel::setIconsize(int iconsize)
 {
-    setPosition(0,PositionBottom,true);
-    gsettings->set(PANEL_POSITION_KEY,0);
-}
-
-void UKUIPanel::changePositionToLeft()
-{
-    setPosition(0,PositionLeft,true);
-    gsettings->set(PANEL_POSITION_KEY,2);
-}
-
-void UKUIPanel::changePositionToRight()
-{
-    this->setPosition(0,PositionRight,true);
-    gsettings->set(PANEL_POSITION_KEY,3);
+    setIconSize(iconsize,true);
+    gsettings->set(ICON_SIZE_KEY,iconsize);
 }
 
+/*Extra code will be deleted*/
 void UKUIPanel::changeSizeToSmall()
 {
     setPanelSize(PANEL_SIZE_SMALL,true);
@@ -1639,8 +1764,8 @@ void UKUIPanel::changeSizeToLarge()
 
 void UKUIPanel::panelReset()
 {
-    QFile::remove(QString(qgetenv("HOME"))+"/.config/lxqt/panel.conf");
-    system("killall ukui-panel");
+    QFile::remove(QString(qgetenv("HOME"))+"/.config/ukui/panel.conf");
+    QFile::copy("/usr/share/ukui/panel.conf",QString(qgetenv("HOME"))+"/.config/ukui/panel.conf");
 }
 void UKUIPanel::panelBackgroundChange()
 {
