@@ -35,9 +35,12 @@
 #include <QPointer>
 #include <QDesktopWidget>
 #include <QGSettings/QGSettings>
+#include <QtDBus/QtDBus>
 #include "common/ukuisettings.h"
 #include "iukuipanel.h"
+#include "popupmenu.h"
 #include "ukuipanelglobals.h"
+#include "highlight-effect.h"
 
 class QMenu;
 class Plugin;
@@ -81,6 +84,8 @@ class UKUI_PANEL_API UKUIPanel : public QFrame, public IUKUIPanel
 
     Q_PROPERTY(QString position READ qssPosition)
 
+    Q_CLASSINFO("D-Bus Interface", "com.ukui.panel.settings")
+
     // for configuration dialog
     friend class ConfigPanelWidget;
     friend class ConfigPluginsWidget;
@@ -303,7 +308,6 @@ public slots:
     void setAlignment(UKUIPanel::Alignment value, bool save); //!< \sa setPanelSize()
     void setFontColor(QColor color, bool save); //!< \sa setPanelSize()
     void setBackgroundColor(QColor color, bool save); //!< \sa setPanelSize()
-    void setBackgroundImage(QString path, bool save); //!< \sa setPanelSize()
     void setOpacity(int opacity, bool save); //!< \sa setPanelSize()
     void setReserveSpace(bool reserveSpace, bool save); //!< \sa setPanelSize()
     void setHidable(bool hidable, bool save); //!< \sa setPanelSize()
@@ -311,6 +315,7 @@ public slots:
     void setAnimationTime(int animationTime, bool save); //!< \sa setPanelSize()
     void setShowDelay(int showDelay, bool save); //!< \sa setPanelSize()
     void setIconTheme(const QString& iconTheme);
+    void setPanelBackground(bool effective);
 
     /**
      * @brief Saves the current configuration, i.e. writes the current
@@ -385,6 +390,7 @@ protected:
      * @param event The QShowEvent sent by Qt.
      */
     void showEvent(QShowEvent *event) override;
+//    void paintEvent(QPaintEvent *);
 
 public slots:
     /**
@@ -424,10 +430,12 @@ private slots:
      * 2. UKUi::Application::themeChanged(), i.e. when the user changes
      * the theme.
      */
-    void setPanelStyle();
+    void setUpPanel();
     void systeMonitor();
     void showDesktop();
     void showTaskView();
+    void showNightModeButton();
+    void adjustPanel();
     void realign();
     /**
      * @brief Moves a plugin in PanelPluginsModel, i.e. calls
@@ -698,13 +706,13 @@ private:
     // settings should be kept private for security
     UKUi::Settings *settings() const { return mSettings; }
 
+    PopupMenu * menu;
+
 
 private slots:
     void setPanelPosition(Position position);
-    void changePositionToTop();
-    void changePositionToBottom();
-    void changePositionToLeft();
-    void changePositionToRight();
+    void setPanelsize(int panelsize);
+    void setIconsize(int iconsize);
     void changeSizeToSmall();
     void changeSizeToMedium();
     void changeSizeToLarge();
@@ -713,6 +721,7 @@ private slots:
 
 public:
     QGSettings *gsettings;
+    QGSettings *transparency_gsettings;
 
 };
 
