@@ -35,6 +35,7 @@ var scrollDown_count = 0;
 var selected_date_div = null;
 var NeedChangeCurrentTime = 1;
 var NeedUpdateYijiArea = true;
+var PrevClick = null;
 
 var div_range = {
     year: {
@@ -316,6 +317,100 @@ function scroll_div(event)
     updateUi();
 }
 
+function update_yiji_area_by_date(cur_year,cur_month)
+{
+    "use strict";
+    var year = cur_year;
+    var month = cur_month;
+
+    var hl_table = document.getElementById('hl_table');
+    var current_row;
+    var current_cell;
+
+    if (year !== parseInt(hl_script.id, 10)) {
+        load_hl_script(year);
+        return;
+    }
+
+    if (typeof HuangLi['y' + year] === 'undefined') {
+        for (var row = 0; row < 2; row++) {
+            if (hl_table.rows.length === row) {
+                current_row = hl_table.insertRow(row);
+            } else {
+                current_row = hl_table.rows[row];
+            }
+
+            for (var column = 1; column < 5; column++) {
+                if (current_row.cells.length === column) {
+                    current_cell = current_row.insertCell(column);
+                } else {
+                    current_cell = current_row.cells[column];
+                }
+
+                if (row === 1) {
+                    current_cell.innerHTML = '无数据';
+                } else {
+                    current_cell.innerHTML = '';
+                }
+            }
+        }
+    }
+
+    var day = highlight_day;
+    var month_str = month.toString();
+    var day_str = day.toString();
+    if (month <= 9) {
+        month_str = '0' + month;
+    }
+    if (day <= 9) {
+        day_str = '0' + day;
+    }
+
+    var yi_str = HuangLi['y' + year]['d' + month_str + day_str]['y'];
+    var ji_str = HuangLi['y' + year]['d' + month_str + day_str]['j'];
+    var hl_yi_data = yi_str.split('.');
+    var hl_ji_data = ji_str.split('.');
+
+    for (var row = 0; row < 2; row++) {
+        if (hl_table.rows.length === row) {
+            current_row = hl_table.insertRow(row);
+        } else {
+            current_row = hl_table.rows[row];
+        }
+
+        for (var column = 1; column < 5; column++) {
+            if (current_row.cells.length === column) {
+                current_cell = current_row.insertCell(column);
+            } else {
+                current_cell = current_row.cells[column];
+            }
+                if(0 == row )
+                {
+                    if(hl_yi_data[column-1])
+                    {
+                        current_cell.innerHTML = hl_yi_data[column-1]; 
+                    }
+                    else
+                    {
+                        current_cell.innerHTML =  ''; 
+                    }
+                    
+                }
+                else
+                {
+                    if(hl_ji_data[column-1])
+                    {
+                        current_cell.innerHTML = hl_ji_data[column-1];
+                    }
+                    else
+                    {
+                        current_cell.innerHTML =''; 
+                    }       
+                }
+        }
+    }  
+}
+
 function update_yiji_area() {
     "use strict";
     var year = parseInt(year_selector.value, 10);
@@ -445,7 +540,7 @@ window.onload = function () {
 	    //var zodiac_icon = document.getElementById('zodiac_icon');
             //zodiac_icon.setAttribute("style", "display:none");
 
-           localStorage.setItem('hl_table', "display");
+            localStorage.setItem('hl_table', "display");
            
         } else{
             var hl_table = document.getElementById('hl_table');
@@ -453,7 +548,7 @@ window.onload = function () {
 	  // var zodiac_icon = document.getElementById('zodiac_icon');
           // zodiac_icon.setAttribute("style", "display:block");
 	   //zodiac_icon.setAttribute("style", "padding-top: 33px");
-           localStorage.setItem('hl_table', "hidden");
+       localStorage.setItem('hl_table', "hidden");
        }
     }
     
@@ -579,6 +674,11 @@ window.onload = function () {
 
             var year = parseInt(year_selector.value);
             var month = parseInt(month_selector.value);
+            if(PrevClick != null)
+            {
+                PrevClick.style.border = "none";
+                PrevClick = null;
+            }
             //page  the year ui
             if(document.getElementById('year_div').className ==='visible_div')
             {
@@ -593,7 +693,7 @@ window.onload = function () {
                         // li.children[0].children[index].innerHTML = '<br />';
                         var currentYear = year + index;
                         //li.children[0].children[index].innerHTML= '<br />' + curretYear + '年';
-                        li.children[0].children[index].innerHTML ='<span class="year_month_grid">'+ currentYear+ '月' + '</span>';
+                        li.children[0].children[index].innerHTML ='<span class="year_month_grid">'+ currentYear+ '年' + '</span>';
                         li.children[0].children[index].addEventListener('click', new_month_selected); // new year implies new month
                     }
                 }
@@ -607,7 +707,7 @@ window.onload = function () {
                         // li.children[0].children[index].innerHTML = '<br />';
                         var currentYear = year + index;
                         //li.children[0].children[index].innerHTML=  '<br />'+ curretYear + '年';
-                        li.children[0].children[index].innerHTML ='<span class="year_month_grid">'+ currentYear+ '月'  + '</span>';
+                        li.children[0].children[index].innerHTML ='<span class="year_month_grid">'+ currentYear+ '年'  + '</span>';
                         li.children[0].children[index].addEventListener('click', new_month_selected); // new year implies new month
                     }
                 }
@@ -677,6 +777,11 @@ window.onload = function () {
         convertToNormal();
         year = today.getFullYear();
         month =  today.getMonth();
+        if(PrevClick != null)
+        {
+            PrevClick.style.border = "none";
+            PrevClick = null;
+        }
         create_page(today.getFullYear(), today.getMonth() + 1);
         update_year_month_ui();
 	var header_id=document.getElementById("header");
@@ -714,25 +819,66 @@ function create_page(year, month) {
         } else {
             current_row = calendar.rows[row];
         }
-
         for (var column = 0; column < 7; column++) {
             if (current_row.cells.length === column) {
                 current_cell = current_row.insertCell(column);
                 current_cell.addEventListener('click', function() {
-                    if(this.children[0].innerHTML === "")
+                    // if(this.children[0].innerHTML === "")
+                    // {
+                    //     highlight_day = parseInt(this.children[1].innerHTML);
+                    // }
+                    // else
+                    // {
+                        highlight_day = parseInt(this.children[0].innerHTML);
+                    // }
+                    //highlight_day = parseInt(this.children[0].innerText);
+                    var cur_month = parseInt(month_selector.value);
+                    var cur_year = parseInt(year_selector.value);
+                    if(PrevClick != null)
                     {
-                        highlight_day = parseInt(this.children[1].innerHTML);
+                        PrevClick.style.border = "none";
+                    }
+                    this.style.border = "1px solid #7eb4ea";
+                    PrevClick = this;
+                    if (this.className === 'day_other_month' && highlight_day > 20) {
+                        // var cur_month = parseInt(month_selector.value);
+                        // var cur_year = parseInt(year_selector.value);
+                        if(1 == cur_month)
+                        {
+                            cur_month = 12;
+                            cur_year = cur_year - 1;
+
+                        }
+                        else
+                        {
+                            cur_month = cur_month - 1;
+                        }
+                        // create_page(cur_year, cur_month);
+                        update_right_pane(cur_year, cur_month, highlight_day);
+                        update_yiji_area_by_date(cur_year,cur_month);
+                    }
+                    else if(this.className === 'day_other_month' && highlight_day < 15)
+                    {
+                        // var cur_month = parseInt(month_selector.value);
+                        // var cur_year = parseInt(year_selector.value);
+                        if(12 == cur_month)
+                        {
+                            cur_month = 1;
+                            cur_year = cur_year + 1;
+
+                        }
+                        else
+                        {
+                            cur_month = cur_month + 1; 
+                        }
+                        // create_page(cur_year, cur_month);
+                        update_right_pane(cur_year, cur_month, highlight_day);
+                        update_yiji_area_by_date(cur_year,cur_month);
                     }
                     else
                     {
-                        highlight_day = parseInt(this.children[0].innerHTML);
+                        create_page(parseInt(year_selector.value), parseInt(month_selector.value));
                     }
-
-                    if (this.className === 'day_other_month') {
-                        return;
-                    }
-
-                    create_page(parseInt(year_selector.value), parseInt(month_selector.value));
                 });
             } else {
                 current_cell = current_row.cells[column];
@@ -804,13 +950,24 @@ function create_page(year, month) {
             }
 
             var lunar_day;
-            if (month_stuff['monthData'][index]['lunarFestival']) {
+            if ((month_stuff['monthData'][index]['lunarFestival'])&&(month_stuff['monthData'][index]['solarFestival'])){
+                lunar_day = month_stuff['monthData'][index]['solarFestival'];
+            }else if (month_stuff['monthData'][index]['solarFestival']) {
+               lunar_day = month_stuff['monthData'][index]['solarFestival'];
+            }else if(month_stuff['monthData'][index]['lunarFestival']){
                 lunar_day = month_stuff['monthData'][index]['lunarFestival'];
-//            } else if (month_stuff['monthData'][index]['solarFestival']) {
-//                lunar_day = month_stuff['monthData'][index]['solarFestival'];
-            } else {
+            }else if(month_stuff['monthData'][index]['term']){
+                lunar_day = month_stuff['monthData'][index]['term'];
+            }else {
                 lunar_day = month_stuff['monthData'][index]['lunarDayName'];
             }
+//             if (month_stuff['monthData'][index]['lunarFestival']) {
+//                 lunar_day = month_stuff['monthData'][index]['lunarFestival'];
+// //            } else if (month_stuff['monthData'][index]['solarFestival']) {
+// //                lunar_day = month_stuff['monthData'][index]['solarFestival'];
+//             } else {
+//                 lunar_day = month_stuff['monthData'][index]['lunarDayName'];
+//             }
 
             var worktime = null;
             if (month_stuff['monthData'][index]['worktime'] === 2) {
@@ -832,7 +989,10 @@ function create_page(year, month) {
                                      '<span class="lunar_part">' +
                                      lunar_day +
                                      '</span>';
-            if (worktime && current_cell.className !== 'day_other_month') {
+            // if (worktime && current_cell.className !== 'day_other_month') {
+            //     current_cell.appendChild(worktime);
+            // }
+            if (worktime) {
                 current_cell.appendChild(worktime);
             }
             // if (month_stuff['monthData'][index]['worktime'] === 2) {
@@ -932,7 +1092,6 @@ function popup_div(event) {
     var height = 20;
     if (this.id === 'year_button') {
         div = document.getElementById('year_div');
-
         div_range.year.x_min = x;
         div_range.year.x_max = x + width;
         div_range.year.y_min = y;
@@ -948,7 +1107,6 @@ function popup_div(event) {
         }
     } else if (this.id === 'month_button') {
         div = document.getElementById('month_div');
-
         div_range.month.x_min = x;
         div_range.month.x_max = x + width;
         div_range.month.y_min = y;
@@ -1001,7 +1159,7 @@ function update_right_pane(year, month, day) {
     var ganzhi_month = month_stuff['monthData'][highlight_index]['GanZhiMonth'];
     var ganzhi_day = month_stuff['monthData'][highlight_index]['GanZhiDay'];
     var zodiac = month_stuff['monthData'][highlight_index]['zodiac'];
-    var weekday = weekdays[highlight_index % 7];
+    var weekday = weekdays[(highlight_index + 1) % 7];
 
     var month_str = month.toString();
     if (month <= 9) {
@@ -1024,7 +1182,7 @@ function update_right_pane(year, month, day) {
     updateTime();
     if(NeedUpdateYijiArea)
     {
-        general_datetime_list.children[0].innerHTML = ganzhi_year + '年' + '【' + zodiac + '年' + '】' + ganzhi_month + '月 ' + ganzhi_day + '日';
+        general_datetime_list.children[0].innerHTML = lunar_month_name + lunar_day_name +'&nbsp;&nbsp;&nbsp;&nbsp'+ganzhi_year + '年' + '【' + zodiac + '年' + '】' + ganzhi_month + '月 ' + ganzhi_day + '日';
         update_yiji_area();
     }
     NeedUpdateYijiArea = true;
