@@ -36,6 +36,7 @@
 #include <QScopedArrayPointer>
 #include <QTimer>
 #include <QWheelEvent>
+#include <QProcess>
 #include "../panel/pluginsettings.h"
 #include <QDebug>
 #include <QApplication>
@@ -43,7 +44,10 @@
 #include <QStyleOption>
 #include <glib.h>
 #include <gio/gio.h>
-#define CALENDAR_HEIGHT (40)
+#include <QSize>
+#include <QScreen>
+
+#define CALENDAR_HEIGHT (46)
 #define CALENDAR_WIDTH (104)
 
 #define WEBVIEW_WIDTH (454)
@@ -54,8 +58,15 @@
 #define HOUR_SYSTEM_24_Vertical "hh:mm ddd  MM/dd"
 #define HOUR_SYSTEM_12_Horizontal   "Ahh:mm ddd  yyyy/MM/dd"
 #define HOUR_SYSTEM_12_Vertical   "Ahh:mm ddd  MM/dd"
-#define HOUR_SYSTEM_KEY "hoursystem"
+#define CURRENT_DATE "yyyy/MM/dd dddd"
 
+#define HOUR_SYSTEM_24_Horizontal_CN "hh:mm ddd  yyyy-MM-dd"
+#define HOUR_SYSTEM_24_Vertical_CN "hh:mm ddd  MM-dd"
+#define HOUR_SYSTEM_12_Horizontal_CN   "Ahh:mm ddd  yyyy-MM-dd"
+#define HOUR_SYSTEM_12_Vertical_CN   "Ahh:mm ddd  MM-dd"
+#define CURRENT_DATE_CN "yyyy-MM-dd dddd"
+
+#define HOUR_SYSTEM_KEY "hoursystem"
 IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupInfo):
     QWidget(),
     IUKUIPanelPlugin(startupInfo),
@@ -75,22 +86,25 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
     mContent = new CalendarActiveLabel(this);
     mWebViewDiag = new UkuiWebviewDialog;
 
-    mRotatedWidget = new UKUi::RotatedWidget(*mContent, mMainWidget);
-
-    mRotatedWidget->setTransferWheelEvent(true);
-
     QVBoxLayout *borderLayout = new QVBoxLayout(mMainWidget);
     borderLayout->setContentsMargins(0, 0, 0, 0);
     borderLayout->setSpacing(0);
-    borderLayout->addWidget(mRotatedWidget, 0, Qt::AlignCenter);
+    borderLayout->setAlignment(Qt::AlignCenter);
+    borderLayout->addWidget(mContent);
 
     mContent->setObjectName(QLatin1String("WorldClockContent"));
-
     mContent->setAlignment(Qt::AlignCenter);
 
     settingsChanged();
     initializeCalendar();
     mTimer->setTimerType(Qt::PreciseTimer);
+
+    hourSystem_24_horzontal=HOUR_SYSTEM_24_Horizontal;
+    hourSystem_24_vartical=HOUR_SYSTEM_24_Vertical;
+    hourSystem_12_horzontal=HOUR_SYSTEM_12_Horizontal;
+    hourSystem_12_vartical=HOUR_SYSTEM_12_Vertical;
+    current_date=CURRENT_DATE;
+
     connect(mTimer, SIGNAL(timeout()), SLOT(timeout()));
     connect(mContent, SIGNAL(wheelScrolled(int)), SLOT(wheelScrolled(int)));
     connect(mWebViewDiag, SIGNAL(deactivated()), SLOT(hidewebview()));
@@ -121,31 +135,38 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
             mbHasCreatedWebView = false;
             initializeCalendar();
         }
+        else if(key == "date")
+        {
+            qDebug()<<"key == date";
+            if(gsettings->keys().contains("date"))
+            {
+                if(QString::compare(gsettings->get("date").toString(),"cn"))
+                {
+                    qDebug()<<" date   en ";
+                    hourSystem_24_horzontal=HOUR_SYSTEM_24_Horizontal_CN;
+                    hourSystem_24_vartical=HOUR_SYSTEM_24_Vertical_CN;
+                    hourSystem_12_horzontal=HOUR_SYSTEM_12_Horizontal_CN;
+                    hourSystem_12_vartical=HOUR_SYSTEM_12_Vertical_CN;
+                    current_date=CURRENT_DATE_CN;
+                }
+                else
+                {
+                    qDebug()<<" date   cn ";
+                    hourSystem_24_horzontal=HOUR_SYSTEM_24_Horizontal;
+                    hourSystem_24_vartical=HOUR_SYSTEM_24_Vertical;
+                    hourSystem_12_horzontal=HOUR_SYSTEM_12_Horizontal;
+                    hourSystem_12_vartical=HOUR_SYSTEM_12_Vertical;
+                    current_date=CURRENT_DATE;
+                }
+            }
+            updateTimeText();
+        }
     });
     }
 
     setTimeShowStyle();
-    mContent->setStyleSheet(
-                //正常状态样式
-                "QLabel{"
-                /*"background-color:rgba(100,225,100,80%);"//背景色（也可以设置图片）*/
-                "border-width:0px;"                     //边框宽度像素
-                "border-radius:6px;"                   //边框圆角半径像素
-                "color:rgba(255,255,255,100%);"                //字体颜色
-                "padding:0px;"                          //填衬
-                "textalignment:aligncenter"               //文本居中
-                "}"
-                //鼠标悬停样式
-                "QLabel:hover{"
-                "background-color:rgba(190,216,239,20%);"
-                "}"
-                //鼠标按下样式
-                "QLabel:pressed{"
-                "background-color:rgba(190,216,239,12%);"
-                "}"
-
-                );
     mContent->setWordWrap(true);
+    setToolTip();
 }
 
 IndicatorCalendar::~IndicatorCalendar()
@@ -158,10 +179,6 @@ IndicatorCalendar::~IndicatorCalendar()
     {
         mWebViewDiag->deleteLater();
     }
-    if(mRotatedWidget != NULL)
-    {
-        mRotatedWidget->deleteLater();
-    }
     if(mContent != NULL)
     {
         mContent->deleteLater();
@@ -172,11 +189,23 @@ IndicatorCalendar::~IndicatorCalendar()
     }
 }
 
+void IndicatorCalendar::setToolTip()
+{
+    QDateTime now = QDateTime::currentDateTime();
+    QString timeZoneName = mActiveTimeZone;
+    if (timeZoneName == QLatin1String("local"))
+        timeZoneName = QString::fromLatin1(QTimeZone::systemTimeZoneId());
+    QTimeZone timeZone(timeZoneName.toLatin1());
+    QDateTime tzNow = now.toTimeZone(timeZone);
+    mContent->setToolTip(tzNow.toString(CURRENT_DATE));
+}
+
 void IndicatorCalendar::timeout()
 {
     if (QDateTime{}.time().msec() > 500)
         restartTimer();
     updateTimeText();
+    setToolTip();
 }
 
 void IndicatorCalendar::updateTimeText()
@@ -226,71 +255,70 @@ void IndicatorCalendar::updateTimeText()
         }
     }
 
-//    if (!isUpToDate || mbIsNeedUpdate)
-//    {
-        const QSize old_size = mContent->sizeHint();
-        QString str;
-        const QByteArray id(HOUR_SYSTEM_CONTROL);
-        if(QGSettings::isSchemaInstalled(id))
-        {
+    //    if (!isUpToDate || mbIsNeedUpdate)
+    //    {
+    const QSize old_size = mContent->sizeHint();
+    QString str;
+    const QByteArray id(HOUR_SYSTEM_CONTROL);
+    if(QGSettings::isSchemaInstalled(id))
+    {
         gsettings = new QGSettings(id);
         QStringList keys = gsettings->keys();
-        if(keys.contains("hoursystem")){
+        if(keys.contains("hoursystem"))
             hourSystemMode=gsettings->get("hoursystem").toString();
-        }
         if(!gsettings)
-        {
-            qDebug()<<"gsettings  get error    :";
             return;
-        }
         if(!QString::compare("24",hourSystemMode))
         {
             if(panel()->isHorizontal())
-            {
-                str=tzNow.toString(HOUR_SYSTEM_24_Horizontal);
-//                str=tzNow.toString(HOUR_SYSTEM_24_Horizontal);
-            }
+                str=tzNow.toString(hourSystem_24_horzontal);
             else
-            {
-                str=tzNow.toString(HOUR_SYSTEM_24_Vertical);
-            }
-
+                str=tzNow.toString(hourSystem_24_vartical);
         }
         else
         {
             if(panel()->isHorizontal())
             {
-                str=tzNow.toString(HOUR_SYSTEM_12_Horizontal);
+                str=tzNow.toString(hourSystem_12_horzontal);
             }
             else
             {
-                str = tzNow.toString(HOUR_SYSTEM_12_Vertical);
+                str = tzNow.toString(hourSystem_12_vartical);
                 str.replace("AM","AM ");
                 str.replace("PM","PM ");
             }
         }
-//        if(QLocale::system().name() == "zh_CN")
-//        {
-//            str.replace("-","/");
-//            str.replace("星期","周");
-//            str.remove("/上午");
-//            str.remove("/下午");
-//            mContent->setText(str);
-//        }
-//        else
-//        {
-//            mContent->setText(tzNow.toString("Ahh:mm ddd  yyyy/MM/dd"));
-//        }
-        mContent->setText(str);
-        if (old_size != mContent->sizeHint())
-        {
-            mRotatedWidget->adjustContentSize();
-        }
-        mRotatedWidget->update();
-        updatePopupContent();
-        mbIsNeedUpdate = false;
-        }
-
+    }
+    else
+    {
+        if(panel()->isHorizontal())
+            str=tzNow.toString(hourSystem_24_horzontal);
+        else
+            str=tzNow.toString(hourSystem_24_vartical);
+    }
+    mContent->setText(str);
+    mContent->setStyleSheet(
+                //正常状态样式
+                "QLabel{"
+                "border-width:  0px;"                     //边框宽度像素
+                "border-radius: 6px;"                       //边框圆角半径像素
+                "font-size:     14px;"                      //字体，字体大小
+                "color:         rgba(255,255,255,100%);"    //字体颜色
+                "padding:       0px;"                       //填衬
+                "text-align:center;"                        //文本居中
+                "}"
+                //鼠标悬停样式
+                "QLabel:hover{"
+                "background-color:rgba(190,216,239,20%);"
+                "border-radius:6px;"                       //边框圆角半径像素
+                "}"
+                //鼠标按下样式
+                "QLabel:pressed{"
+                "background-color:rgba(190,216,239,12%);"
+                "}"
+                );
+    updatePopupContent();
+    mbIsNeedUpdate = false;
 }
 
 void IndicatorCalendar::setTimeText()
@@ -509,13 +537,17 @@ void IndicatorCalendar::initializeCalendar()
     CalendarShowMode showCalendar = defaultMode;
     QString lunarOrsolar;
     QString firstDay;
+    int iScreenHeight = QApplication::screens().at(0)->size().height() - panel()->panelSize();
+    if(iScreenHeight > WEBVIEW_MAX_HEIGHT)
+    {
+        mViewHeight = WEBVIEW_MAX_HEIGHT;
+    }
+    else
+    {
+        mViewHeight = WEBVIEW_MIN_HEIGHT;
+    }
     if(QGSettings::isSchemaInstalled(id))
     {
-//        if(gsettings)
-//        {
-//            gsettings->deleteLater();
-//        }
-//        gsettings = new QGSettings(id);
         if(!gsettings)
         {
             qDebug()<<"get gsetting error!!!";
@@ -543,7 +575,14 @@ void IndicatorCalendar::initializeCalendar()
                 {
                     showCalendar = lunarMonday;
                 }
-                mViewHeight = WEBVIEW_MAX_HEIGHT;
+                if(iScreenHeight > WEBVIEW_MAX_HEIGHT)
+                {
+                    mViewHeight = WEBVIEW_MAX_HEIGHT;
+                }
+                else
+                {
+                    mViewHeight = WEBVIEW_MIN_HEIGHT;
+                }
             }
             else if(lunarOrsolar == "solarlunar")
             {
@@ -577,7 +616,7 @@ void IndicatorCalendar::initializeCalendar()
         if(!mbHasCreatedWebView)
         {
             qDebug()<<"showCalendar:"<<showCalendar;
-            mWebViewDiag->creatwebview(showCalendar);
+            mWebViewDiag->creatwebview(showCalendar,panel()->panelSize());
             mbHasCreatedWebView = true;
         }
     }
@@ -587,15 +626,24 @@ void IndicatorCalendar::activated(ActivationReason reason)
 {
     if(mWebViewDiag != NULL )
     {
-//        QString  htmlFilePath = QLatin1String(PACKAGE_DATA_DIR);
-//        htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui.html");
-
+        mViewHeight = WEBVIEW_MAX_HEIGHT;
+        if(gsettings->get("calendar").toString() == "solarlunar")
+            mViewHeight = WEBVIEW_MIN_HEIGHT;
+        if (QLocale::system().name() != "zh_CN")
+            mViewHeight = WEBVIEW_MIN_HEIGHT;
+        int iScreenHeight = QApplication::screens().at(0)->size().height() - panel()->panelSize();
+        if (iScreenHeight < WEBVIEW_MAX_HEIGHT) {
+            mViewHeight = iScreenHeight;
+            if (iScreenHeight >= WEBVIEW_MIN_HEIGHT)
+                mViewHeight = WEBVIEW_MIN_HEIGHT;;
+        }
         mWebViewDiag->setGeometry(calculatePopupWindowPos(QSize(mViewWidht,mViewHeight)));
         mWebViewDiag->show();
         setbackground();
         if(!mbActived)
         {
             mWebViewDiag->setHidden(false);
+            mWebViewDiag->webview()->reload();
             mbActived = true;
         }
         else
@@ -635,7 +683,13 @@ void IndicatorCalendar::updatePopupContent()
         QStringList allTimeZones;
         bool hasTimeZone = formatHasTimeZone(mFormat);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+        QString timeZoneName;
+        for (QStringList::iterator it = mTimeZones.begin(); it != mTimeZones.end(); ++it)
+#endif
+#if (QT_VERSION >= QT_VERSION_CHECK(5,7,0))
         for (QString timeZoneName : qAsConst(mTimeZones))
+#endif
         {
             if (timeZoneName == QLatin1String("local"))
                 timeZoneName = QString::fromLatin1(QTimeZone::systemTimeZoneId());
@@ -749,37 +803,18 @@ QString IndicatorCalendar::preformat(const QDateTime &dateTime,const QString &fo
 void IndicatorCalendar::realign()
 {
     setTimeShowStyle();
-    if (mAutoRotate)
-        switch (panel()->position())
-        {
-        case IUKUIPanel::PositionTop:
-        case IUKUIPanel::PositionBottom:
-            mRotatedWidget->setOrigin(Qt::TopLeftCorner);
-            break;
-
-        case IUKUIPanel::PositionLeft:
-            //mRotatedWidget->setOrigin(Qt::BottomLeftCorner);
-            break;
-
-        case IUKUIPanel::PositionRight:
-            //mRotatedWidget->setOrigin(Qt::TopRightCorner);
-            break;
-        }
-    else
-    {
-        mRotatedWidget->setOrigin(Qt::TopLeftCorner);
-    }
 }
 
 void IndicatorCalendar::setTimeShowStyle()
 {
+    int size = panel()->panelSize() - 3;
     if(panel()->isHorizontal())
     {
-        mContent->setFixedSize(CALENDAR_WIDTH,CALENDAR_HEIGHT);
+       mContent->setFixedSize(CALENDAR_WIDTH, size);
     }
     else
     {
-        mContent->setFixedSize(CALENDAR_HEIGHT,CALENDAR_WIDTH);
+        mContent->setFixedSize(size, CALENDAR_WIDTH);
     }
     mbIsNeedUpdate = true;
     timeout();
@@ -951,23 +986,23 @@ void CalendarActiveLabel::contextMenuEvent(QContextMenuEvent *event)
                    tr("Time and Date Setting"),
                    this, SLOT(setControlTime())
                   );
-    /*
     menuCalender->addAction(QIcon::fromTheme("document-page-setup"),
                    tr("Config panel"),
                    this, SLOT(setUpPanel())
                   );
-    */
     menuCalender->setGeometry(mPlugin->panel()->calculatePopupWindowPos(mapToGlobal(event->pos()), menuCalender->sizeHint()));
     menuCalender->show();
 }
 
 void CalendarActiveLabel::setControlTime()
 {
-    system("ukui-control-center");
+    QProcess *process =new QProcess(this);
+    process->startDetached("ukui-control-center -t");
 }
-/*
+
 void CalendarActiveLabel::setUpPanel()
 {
-    system("ukui-control-center -d");
+    QProcess *process =new QProcess(this);
+    process->startDetached("ukui-control-center -d");
 }
-*/
+
