@@ -59,6 +59,7 @@ public:
     void initializeCalendar();
     void setbackground();
     void setTimeShowStyle();
+    void setToolTip();
 //signals:
 Q_SIGNALS:
     void deactivated();
@@ -73,7 +74,6 @@ private Q_SLOTS:
 private:
     QWidget *mMainWidget;
     UkuiWebviewDialog   *mWebViewDiag;
-    UKUi::RotatedWidget* mRotatedWidget;
     bool mbActived;
     bool mbHasCreatedWebView;
     CalendarActiveLabel *mContent;
@@ -105,6 +105,13 @@ private:
     bool mbIsNeedUpdate;
     QGSettings *gsettings;
     QString hourSystemMode;
+
+    QString hourSystem_24_horzontal;
+    QString hourSystem_24_vartical;
+    QString hourSystem_12_horzontal;
+    QString hourSystem_12_vartical;
+    QString current_date;
+
 };
 
 
@@ -127,7 +134,7 @@ protected:
 
 private Q_SLOTS:
     void setControlTime();
-    //void setUpPanel();
+    void setUpPanel();
 
 private:
     IUKUIPanelPlugin * mPlugin;
