@@ -1,4 +1,4 @@
-﻿/*
+/*
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,16 @@
 #include <QMessageBox>
 #include <QColor>
 #include <QTime>
+#include <QApplication>
+#include <QSize>
+#include <QScreen>
+#include <QBitmap>
+#include <QPainter>
+
+#define CALENDAR_MAX_HEIGHT 704
+#define CALENDAR_MIN_HEIGHT 600
+
+#define CALENDAR_MAX_WIDTH 454
 
 UkuiWebviewDialog::UkuiWebviewDialog(QWidget *parent) :
     QDialog(parent, Qt::Popup),
@@ -43,10 +53,11 @@ UkuiWebviewDialog::~UkuiWebviewDialog()
     }
 }
 
-void UkuiWebviewDialog::creatwebview(int _mode)
+void UkuiWebviewDialog::creatwebview(int _mode, int _panelSize)
 {
-    int iViewWidth = 454;
-    int iViewHeight = 704;
+    int iViewWidth = CALENDAR_MAX_WIDTH;
+    int iViewHeight = CALENDAR_MAX_HEIGHT;
+    int iScreenHeight = QApplication::screens().at(0)->size().height() - _panelSize;
     if(!mWebView)
     {
          mWebView = new QWebView(this);
@@ -63,8 +74,15 @@ void UkuiWebviewDialog::creatwebview(int _mode)
             if(_mode == lunarMonday)
             {
                 //first day a week is monday in lunar mode
-                iViewHeight = 704;
-                htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui-mon.html");
+                if(CALENDAR_MAX_HEIGHT < iScreenHeight)
+                {
+                    htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui-mon.html");
+                }
+                else
+                {
+                    iViewHeight = CALENDAR_MIN_HEIGHT;
+                    htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui-mon-min.html");
+                }
             }
             else if(_mode == solarSunday)
             {
@@ -81,7 +99,15 @@ void UkuiWebviewDialog::creatwebview(int _mode)
             else
             {
                 //first day a week is sunday in lunar mode
-                htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui.html");
+                if(CALENDAR_MAX_HEIGHT < iScreenHeight)
+                {
+                    htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui.html");
+                }
+                else
+                {
+                    iViewHeight = 600;
+                    htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui-min.html");
+                }
             }
         }
         else
@@ -96,10 +122,18 @@ void UkuiWebviewDialog::creatwebview(int _mode)
             }
             iViewHeight = 600;
         }
-//        htmlFilePath = QLatin1String("file://") + QLatin1String(PACKAGE_DATA_DIR) + QLatin1String("/plugin-calendar/html/ukui-solar-en.html");
-        qDebug()<<"load html-----------------------------"<<htmlFilePath;
         /*set window no margins*/
         mWebView->setWindowFlags(Qt::FramelessWindowHint);
+
+        /*set rounded corner ,including radius*/
+        QBitmap bmp(iViewWidth,iViewHeight);
+        bmp.fill();
+        QPainter p(&bmp);
+        p.setPen(Qt::NoPen);
+        p.setBrush(Qt::black);
+        p.drawRoundedRect(bmp.rect(),6,6);
+        setMask(bmp);
+
         /*set window size*/
         mWebView->resize(iViewWidth,iViewHeight);
         mWebView->settings()->setAttribute(QWebSettings::JavascriptEnabled,true);
