@@ -47,6 +47,8 @@ QuickLaunchButton::QuickLaunchButton(QuickLaunchAction * act, IUKUIPanelPlugin *
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setAcceptDrops(true);
+    /*设置快速启动栏的按键不接受焦点　　*/
+    setFocusPolicy(Qt::NoFocus);
     setAutoRaise(true);
     quicklanuchstatus = NORMAL;
 
@@ -97,7 +99,7 @@ QHash<QString,QString> QuickLaunchButton::settingsMap()
     return mAct->settingsMap();
 }
 
-
+/*与鼠标右键的选项有关*/
 void QuickLaunchButton::this_customContextMenuRequested(const QPoint & pos)
 {
    UKUIQuickLaunch *panel = qobject_cast<UKUIQuickLaunch*>(parent());
@@ -114,6 +116,7 @@ void QuickLaunchButton::selfRemove()
     emit buttonDeleted();
 }
 
+/*quicklanuchstatus的状态*/
 void QuickLaunchButton::enterEvent(QEvent *)
 {
     quicklanuchstatus =HOVER;
