@@ -53,18 +53,23 @@ UKUIStartMenuButton::UKUIStartMenuButton( IUKUIPanelPlugin *plugin, QWidget* par
 {
     this->setIcon(QIcon("/usr/share/ukui-panel/panel/img/startmenu.svg"));
     this->setStyle(new CustomStyle());
+//    this->setWindowFlags(Qt::NoFocus);
+    setAttribute(Qt::WA_X11DoNotAcceptFocus, true);
+    setAttribute(Qt::WA_ShowWithoutActivating,true);
+    setFocusPolicy(Qt::NoFocus);
 }
 
 UKUIStartMenuButton::~UKUIStartMenuButton()
 {
 }
 
+/*plugin-startmenu refresh function*/
 void UKUIStartMenuButton::realign()
 {
     if (mPlugin->panel()->isHorizontal())
-        this->setFixedSize(mPlugin->panel()->panelSize(),mPlugin->panel()->panelSize());
+        this->setFixedSize(mPlugin->panel()->panelSize()+14,mPlugin->panel()->panelSize());
     else
-       this->setFixedSize(mPlugin->panel()->panelSize(),mPlugin->panel()->panelSize());
+       this->setFixedSize(mPlugin->panel()->panelSize(),mPlugin->panel()->panelSize()+14);
     this->setIconSize(QSize(mPlugin->panel()->iconSize(),mPlugin->panel()->iconSize()));
 }
 
@@ -88,27 +93,28 @@ void UKUIStartMenuButton::contextMenuEvent(QContextMenuEvent *event)
 {
     rightPressMenu=new QMenu();
     rightPressMenu->setAttribute(Qt::WA_DeleteOnClose);
+    rightPressMenu->setWindowOpacity(0.7);
 
-    rightPressMenu->addAction(XdgIcon::fromTheme(QLatin1String("system-lock-screen")),
+    rightPressMenu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("system-lock-screen-symbolic").pixmap(24,24).toImage()))),
                               tr("Lock Screen"),
                               this, SLOT(ScreenServer())
                               );
-    rightPressMenu->addAction(XdgIcon::fromTheme(QLatin1String("stock-people")),
+    rightPressMenu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("stock-people-symbolic").pixmap(24,24).toImage()))),
                               tr("Switch User"),
                               this, SLOT(SessionSwitch())
                               );
 
-    rightPressMenu->addAction(XdgIcon::fromTheme(QLatin1String("system-logout")),
+    rightPressMenu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("system-logout-symbolic").pixmap(24,24).toImage()))),
                               tr("LogOut"),
                               this, SLOT(SessionLogout())
                               );
 
-    rightPressMenu->addAction(XdgIcon::fromTheme(QLatin1String("system-restart")),
+    rightPressMenu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("system-restart-symbolic").pixmap(24,24).toImage()))),
                               tr("Restart"),
                               this, SLOT(SessionReboot())
                               );
 
-    rightPressMenu->addAction(XdgIcon::fromTheme(QLatin1String("exit")),
+    rightPressMenu->addAction(QIcon(HighLightEffect::drawSymbolicColoredPixmap(QPixmap::fromImage(QIcon::fromTheme("exit-symbolic").pixmap(24,24).toImage()))),
                               tr("Power Off"),
                               this, SLOT(SessionShutdown())
                               );
@@ -117,6 +123,7 @@ void UKUIStartMenuButton::contextMenuEvent(QContextMenuEvent *event)
     rightPressMenu->show();
 }
 
+/*开始菜单按钮右键菜单选项，与开始菜单中电源按钮的右键功能是相同的*/
 void UKUIStartMenuButton::ScreenServer()
 {
     system("ukui-screensaver-command -l");
