@@ -26,18 +26,17 @@
 #include <QFontMetrics>
 #include <QLineEdit>
 #include <QToolButton>
-#include <XdgIcon>
 #include <QMainWindow>
 #include <QHBoxLayout>
 #include <QDebug>
 #include <QProcess>
-#include "../panel/plugin.h"
+//#include "../panel/plugin.h"
 #include "../panel/ukuipanel.h"
-#include "../panel/config/configpanelwidget.h"
-#include <../panel/popupmenu.h>
-#include "../panel/iukuipanelplugin.h"
+//#include "../panel/config/configpanelwidget.h"
+//#include <../panel/popupmenu.h>
 #include <QMenu>
 #include <QPointF>
+#include "../panel/highlight-effect.h"
 
 class UKUIStartMenuButton;
 class UKUIStartMenuPlugin: public QObject, public IUKUIPanelPlugin
