@@ -41,10 +41,10 @@
 #include <QTimer>
 
 #include "../panel/common/ukuigridlayout.h"
-#include <XdgIcon>
 
 #include "ukuitaskbar.h"
 #include "ukuitaskgroup.h"
+#include "ukuitaskbaricon.h"
 using namespace UKUi;
 
 /************************************************
@@ -53,12 +53,12 @@ using namespace UKUi;
 UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     QFrame(parent),
     mSignalMapper(new QSignalMapper(this)),
-    mButtonStyle(Qt::ToolButtonTextBesideIcon),
+    mButtonStyle(Qt::ToolButtonIconOnly),
     mButtonWidth(400),
     mButtonHeight(100),
     mCloseOnMiddleClick(true),
     mRaiseOnCurrentDesktop(true),
-    mShowOnlyOneDesktopTasks(false),
+    mShowOnlyOneDesktopTasks(true),
     mShowDesktopNum(0),
     mShowOnlyCurrentScreenTasks(false),
     mShowOnlyMinimizedTasks(false),
@@ -75,7 +75,8 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     setAttribute(Qt::WA_TranslucentBackground);//设置窗口背景透明
     setWindowFlags(Qt::FramelessWindowHint);   //设置无边框窗口
 
-    setStyle(mStyle);
+    //setStyle(mStyle);
+    mpTaskBarIcon = new UKUITaskBarIcon;
     mLayout = new UKUi::GridLayout(this);
     setLayout(mLayout);
     mLayout->setMargin(0);
@@ -87,8 +88,11 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     mPlaceHolder->setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
     mPlaceHolder->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
     mLayout->addWidget(mPlaceHolder);
+    QTimer::singleShot(0, this, SLOT(refreshPlaceholderVisibility()));
 
-    QTimer::singleShot(0, this, SLOT(settingsChanged()));
+//    QTimer::singleShot(0, this, SLOT(settingsChanged()));
+    settingsChanged();
+//    setButtonStyle(Qt::ToolButtonIconOnly);
     setAcceptDrops(true);
 
     connect(mSignalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &UKUITaskBar::activateTask);
@@ -98,6 +102,22 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
             , this, &UKUITaskBar::onWindowChanged);
     connect(KWindowSystem::self(), &KWindowSystem::windowAdded, this, &UKUITaskBar::onWindowAdded);
     connect(KWindowSystem::self(), &KWindowSystem::windowRemoved, this, &UKUITaskBar::onWindowRemoved);
+
+    //龙芯机器的最小化任务窗口的预览窗口的特殊处理
+    system("cat /proc/cpuinfo >> /tmp/_tmp_cpu_info_cat_");
+    QFile file("/tmp/_tmp_cpu_info_cat_");
+    if (!file.open(QIODevice::ReadOnly)) qDebug() << "Read CpuInfo Failed.";
+    while (CpuInfoFlg && !file.atEnd()) {
+        QByteArray line = file.readLine();
+        QString str(line);
+        if (str.contains("Loongson")) CpuInfoFlg = false;
+    }
+    file.close();
+
+    /**/
+    QDBusConnection::sessionBus().unregisterService("com.ukui.panel.plugins.service");
+    QDBusConnection::sessionBus().registerService("com.ukui.panel.plugins.service");
+    QDBusConnection::sessionBus().registerObject("/taskbar/click", this,QDBusConnection :: ExportAllSlots | QDBusConnection :: ExportAllSignals);
 }
 
 /************************************************
@@ -106,6 +126,11 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
 UKUITaskBar::~UKUITaskBar()
 {
     delete mStyle;
+    if(mpTaskBarIcon)
+    {
+        delete mpTaskBarIcon;
+        mpTaskBarIcon = nullptr;
+    }
 }
 
 /************************************************
@@ -273,7 +298,12 @@ void UKUITaskBar::addWindow(WId window)
 {
     // If grouping disabled group behaves like regular button
     const QString group_id = mGroupingEnabled ? KWindowInfo(window, 0, NET::WM2WindowClass).windowClassClass() : QString("%1").arg(window);
-
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+    if(!group_id.compare("peony-qt-desktop"))
+    {
+        return;
+    }
+#endif
     UKUITaskGroup *group = nullptr;
     auto i_group = mKnownWindows.find(window);
     if (mKnownWindows.end() != i_group)
@@ -284,8 +314,11 @@ void UKUITaskBar::addWindow(WId window)
             (*i_group)->onWindowRemoved(window);
     }
 
-    //check if window belongs to some existing group
-    if (!group && mGroupingEnabled)
+    /*check if window belongs to some existing group
+     * 安卓兼容应用的组名为kydroid-display-window
+     * 需要将安卓兼容目录的分组特性关闭
+    */
+    if (!group && mGroupingEnabled && group_id.compare("kydroid-display-window"))
     {
         for (auto i = mKnownWindows.cbegin(), i_e = mKnownWindows.cend(); i != i_e; ++i)
         {
@@ -307,7 +340,7 @@ void UKUITaskBar::addWindow(WId window)
             buttonMove(qobject_cast<UKUITaskGroup *>(sender()), qobject_cast<UKUITaskGroup *>(dragSource), pos);
         });
 
-        group->setFixedSize(panel()->panelSize(),panel()->panelSize());
+        //group->setFixedSize(panel()->panelSize(),panel()->panelSize());
         mLayout->addWidget(group);
         group->setToolButtonsStyle(mButtonStyle);
     }
@@ -436,20 +469,9 @@ void UKUITaskBar::refreshPlaceholderVisibility()
  ************************************************/
 void UKUITaskBar::setButtonStyle(Qt::ToolButtonStyle buttonStyle)
 {
-    const Qt::ToolButtonStyle old_style = mButtonStyle;
-    mButtonStyle = buttonStyle;
-    if (old_style != mButtonStyle)
-        emit buttonStyleRefreshed(mButtonStyle);
+    emit buttonStyleRefreshed(mButtonStyle);
 }
 
-void UKUITaskBar::setShowGroupOnHover(bool bFlag)
-{
-    mShowGroupOnHover = bFlag;
-}
-
-/************************************************
-
- ************************************************/
 void UKUITaskBar::settingsChanged()
 {
     bool groupingEnabledOld = mGroupingEnabled;
@@ -509,9 +531,11 @@ void UKUITaskBar::settingsChanged()
     refreshTaskList();
 }
 
-/************************************************
+void UKUITaskBar::setShowGroupOnHover(bool bFlag)
+{
+    mShowGroupOnHover = bFlag;
+}
 
- ************************************************/
 void UKUITaskBar::realign()
 {
     mLayout->setEnabled(false);
@@ -519,8 +543,8 @@ void UKUITaskBar::realign()
 
     IUKUIPanel *panel = mPlugin->panel();
     //set taskbar width by panel
-    QSize maxSize = QSize(100, mButtonHeight);
-    QSize minSize = QSize(0, 0);
+    QSize maxSize = QSize(mPlugin->panel()->panelSize(), mPlugin->panel()->panelSize());
+    QSize minSize = QSize(mPlugin->panel()->iconSize()/2, mPlugin->panel()->iconSize()/2);
     int iconsize = panel->iconSize();
     int panelsize = panel->panelSize();
 
@@ -561,9 +585,9 @@ void UKUITaskBar::realign()
     for(auto it= mKnownWindows.begin(); it != mKnownWindows.end();it++)
     {
         UKUITaskGroup *group = it.value();
-        group->setFixedSize(panelsize, panelsize);
+        //group->setFixedSize(panelsize, panelsize);
         group->setIconSize(QSize(iconsize,iconsize));
-        group->updateIcon();
+//        group->updateIcon();
     }
     mLayout->setCellMinimumSize(minSize);
     mLayout->setCellMaximumSize(maxSize);
@@ -755,7 +779,34 @@ void UKUITaskBar::paintEvent(QPaintEvent *)
                   break;
               }
           }
-        p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+        p.setRenderHint(QPainter::Antialiasing);
         p.drawRoundedRect(opt.rect,6,6);
         style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
 }
+
+void UKUITaskBar::mousePressEvent(QMouseEvent *)
+{
+    /*创建QT的DBus信号*/
+    QDBusMessage message =QDBusMessage::createSignal("/taskbar/click", "com.ukui.panel.plugins.taskbar", "sendToUkuiDEApp");
+    /*
+     * 发射信号,此处不给信号赋值　　message << QString("clicked");的原因是
+     * 侧边栏和开始菜单仅需要点击信号
+     * 若后期有特殊的设计需求，例如对鼠标左键，右键，滚轮　进行不同的处理就需要给信号赋值
+     * tr:
+     * Transmit the signal, the signal is not assigned here The reason is
+     * The sidebar and start menu only need to click the signal
+     * If there are special design requirements in the later stage,
+     * such as different processing for the left mouse button, right mouse button, and scroll wheel,
+     * the signal needs to be assigned and processed
+     *
+     * 需要此点击信号的应用需要做如下绑定
+     * QDBusConnection::sessionBus().connect(QString(), QString("/taskbar/click"), "com.ukui.panel.plugins.taskbar", "sendToUkuiDEApp", this, SLOT(client_get(void)));
+     * 在槽函数client_get(void)　中处理接受到的点击信号
+     * tr:
+     * Applications that require this click signal need to do the following binding
+     * Process the received click signal in the slot function client_get (void)
+     * NOTE:https://blog.csdn.net/czhzasui/article/details/81071383
+　　　*/
+    QDBusConnection::sessionBus().send(message);
+}
+
