@@ -33,7 +33,6 @@
 
 #include "../panel/iukuipanel.h"
 #include "../panel/iukuipanelplugin.h"
-#include "ukuitaskbarconfiguration.h"
 #include "ukuitaskgroup.h"
 #include "ukuitaskbutton.h"
 
@@ -47,10 +46,12 @@
 #include <KWindowSystem/NETWM>
 #include <QStyleOption>
 #include <QPainter>
+#include <QtDBus/QtDBus>
 
 class QSignalMapper;
 class UKUITaskButton;
 class ElidedButtonStyle;
+class UKUITaskBarIcon;
 
 namespace UKUi {
 class GridLayout;
@@ -60,6 +61,13 @@ class UKUITaskBar : public QFrame
 {
     Q_OBJECT
 
+    /*
+     * 负责与ukui桌面环境应用通信的dbus
+     * 在点击任务栏的时候发给其他UKUI DE APP 点击信号
+     * 以适应特殊的设计需求以及
+　　　*/
+    Q_CLASSINFO("D-Bus Interface", "com.ukui.panel.plugins.taskbar")
+
 public:
     explicit UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget* parent = 0);
     virtual ~UKUITaskBar();
@@ -72,6 +80,7 @@ public:
     bool raiseOnCurrentDesktop() const { return mRaiseOnCurrentDesktop; }
     bool isShowOnlyOneDesktopTasks() const { return mShowOnlyOneDesktopTasks; }
     int showDesktopNum() const { return mShowDesktopNum; }
+    bool getCpuInfoFlg() const { return CpuInfoFlg; }
     bool isShowOnlyCurrentScreenTasks() const { return mShowOnlyCurrentScreenTasks; }
     bool isShowOnlyMinimizedTasks() const { return mShowOnlyMinimizedTasks; }
     bool isAutoRotate() const { return mAutoRotate; }
@@ -81,9 +90,7 @@ public:
     void setShowGroupOnHover(bool bFlag);
     inline IUKUIPanel * panel() const { return mPlugin->panel(); }
     inline IUKUIPanelPlugin * plugin() const { return mPlugin; }
-
-public slots:
-    void settingsChanged();
+    inline UKUITaskBarIcon* fetchIcon()const{return mpTaskBarIcon;}
 
 signals:
     void buttonRotationRefreshed(bool autoRotate, IUKUIPanel::Position position);
@@ -92,6 +99,7 @@ signals:
     void showOnlySettingChanged();
     void iconByClassChanged();
     void popupShown(UKUITaskGroup* sender);
+    void sendToUkuiDEApp(void);
 
 protected:
     virtual void dragEnterEvent(QDragEnterEvent * event);
@@ -99,6 +107,7 @@ protected:
     void enterEvent(QEvent *);
     void leaveEvent(QEvent *);
     void paintEvent(QPaintEvent *);
+    void mousePressEvent(QMouseEvent *);
 
 private slots:
     void refreshTaskList();
@@ -133,6 +142,7 @@ private:
     Qt::ToolButtonStyle mButtonStyle;
     int mButtonWidth;
     int mButtonHeight;
+    bool CpuInfoFlg = true;
     bool mCloseOnMiddleClick;
     bool mRaiseOnCurrentDesktop;
     bool mShowOnlyOneDesktopTasks;
@@ -147,6 +157,7 @@ private:
 
     bool acceptWindow(WId window) const;
     void setButtonStyle(Qt::ToolButtonStyle buttonStyle);
+    void settingsChanged();
 
     void wheelEvent(QWheelEvent* event);
     void changeEvent(QEvent* event);
@@ -155,6 +166,7 @@ private:
     IUKUIPanelPlugin *mPlugin;
     QWidget *mPlaceHolder;
     LeftAlignedTextStyle *mStyle;
+    UKUITaskBarIcon *mpTaskBarIcon;
 };
 
 #endif // UKUITASKBAR_H
