@@ -36,7 +36,6 @@
 #include <QDragLeaveEvent>
 #include <QStringBuilder>
 #include <QMenu>
-#include <XdgIcon>
 #include <KF5/KWindowSystem/KWindowSystem>
 #include <functional>
 
@@ -53,6 +52,8 @@
 #include "../panel/iukuipanelplugin.h"
 #include <QSize>
 #include <QScreen>
+#include "../panel/customstyle.h"
+
 #define PREVIEW_WIDTH		468
 #define PREVIEW_HEIGHT		428
 #define SPACE_WIDTH			8
@@ -61,6 +62,7 @@
 #define THUMBNAIL_HEIGHT	(PREVIEW_HEIGHT - SPACE_HEIGHT)
 #define ICON_WIDTH			48
 #define ICON_HEIGHT			48
+#define MAX_SIZE_OF_Thumb   16777215
 
 #define SCREEN_MAX_WIDTH_SIZE     1400
 #define SCREEN_MAX_HEIGHT_SIZE    1050
@@ -121,18 +123,16 @@ QPixmap qimageFromXImage(XImage* ximage)
             p += ximage->bytes_per_line / 4;
         }
     }
-
     return QPixmap::fromImage(image);
 }
 
 
 
-
 /************************************************
 
  ************************************************/
 UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *parent)
-    : UKUITaskButton(window, parent, parent),
+    : UKUITaskButton(groupName,window, parent, parent),
     mGroupName(groupName),
     mPopup(new UKUIGroupPopup(this)),
     mPreventPopup(false),
@@ -141,6 +141,7 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     mpWidget(NULL)
 {
     Q_ASSERT(parent);
+    mpScrollArea = NULL;
     taskgroupStatus = NORMAL;
 
     setObjectName(groupName);
@@ -149,7 +150,6 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     connect(this, SIGNAL(clicked(bool)), this, SLOT(onClicked(bool)));
     connect(KWindowSystem::self(), SIGNAL(currentDesktopChanged(int)), this, SLOT(onDesktopChanged(int)));
     connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(onActiveWindowChanged(WId)));
-    connect(parent, &UKUITaskBar::buttonRotationRefreshed, this, &UKUITaskGroup::setAutoRotation);
     connect(parent, &UKUITaskBar::refreshIconGeometry, this, &UKUITaskGroup::refreshIconsGeometry);
     connect(parent, &UKUITaskBar::buttonStyleRefreshed, this, &UKUITaskGroup::setToolButtonsStyle);
     connect(parent, &UKUITaskBar::showOnlySettingChanged, this, &UKUITaskGroup::refreshVisibility);
@@ -192,7 +192,7 @@ void UKUITaskGroup::contextMenuEvent(QContextMenuEvent *event)
 
     QMenu * menu = new QMenu(tr("Group"));
     menu->setAttribute(Qt::WA_DeleteOnClose);
-    QAction *a = menu->addAction(XdgIcon::fromTheme("process-stop"), tr("close"));
+    QAction *a = menu->addAction(QIcon::fromTheme("process-stop"), tr("close"));
     connect(a, SIGNAL(triggered()), this, SLOT(closeGroup()));
     connect(menu, &QMenu::aboutToHide, [this] {
         mPreventPopup = false;
@@ -208,9 +208,18 @@ void UKUITaskGroup::contextMenuEvent(QContextMenuEvent *event)
 void UKUITaskGroup::closeGroup()
 {
     //To Do
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+    for(auto it=mButtonHash.begin();it!=mButtonHash.end();it++)
+    {
+    UKUITaskWidget *button =it.value();
+  if (button->isOnDesktop(KWindowSystem::currentDesktop()))
+            button->closeApplication();
+    }
+#else
     for (UKUITaskWidget *button : qAsConst(mButtonHash) )
         if (button->isOnDesktop(KWindowSystem::currentDesktop()))
             button->closeApplication();
+#endif
 }
 
 /************************************************
@@ -223,11 +232,11 @@ QWidget * UKUITaskGroup::addWindow(WId id)
         return mButtonHash.value(id);
     UKUITaskWidget *btn = new UKUITaskWidget(id, parentTaskBar(), mPopup);
     mButtonHash.insert(id, btn);
-
     connect(btn, SIGNAL(clicked()), this, SLOT(onChildButtonClicked()));
     connect(btn, SIGNAL(windowMaximize()), this, SLOT(onChildButtonClicked()));
     refreshVisibility();
 
+    changeTaskButtonStyle();
     return btn;
 }
 
@@ -243,6 +252,16 @@ QWidget * UKUITaskGroup::checkedButton() const
     return NULL;
 }
 
+/*changeTaskButtonStyle in class UKUITaskGroup not class UKUITaskButton
+ * because class UKUITaskButton can not get mButtonHash.size
+ */
+void UKUITaskGroup::changeTaskButtonStyle()
+{
+    if(mButtonHash.size()>1)
+        this->setStyle(new CustomStyle("taskbutton",true));
+    else
+        this->setStyle(new CustomStyle("taskbutton",false));
+}
 /************************************************
 
  ************************************************/
@@ -326,14 +345,17 @@ void UKUITaskGroup::onWindowRemoved(WId window)
     {
         UKUITaskWidget *button = mButtonHash.value(window);
         mButtonHash.remove(window);
+        if (mVisibleHash.contains(window))
+            mVisibleHash.remove(window);
         mPopup->removeWidget(button);
         button->deleteLater();
-
+        if (!parentTaskBar()->getCpuInfoFlg())
+            system(QString("rm -f /tmp/%1.png").arg(window).toLatin1());
         if (mButtonHash.count())
         {
             if(mPopup->isVisible())
             {
-                mPopup->hide();
+//                mPopup->hide(true);
                 showPreview();
             }
             else
@@ -349,6 +371,7 @@ void UKUITaskGroup::onWindowRemoved(WId window)
             emit groupBecomeEmpty(groupName());
 
         }
+        changeTaskButtonStyle();
     }
 }
 
@@ -397,15 +420,34 @@ int UKUITaskGroup::buttonsCount() const
     return mButtonHash.count();
 }
 
+void UKUITaskGroup::initVisibleHash()
+{
+   /* for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    {
+        if (mVisibleHash.contains(it.key())) continue;
+        if (it.value()->isVisibleTo(mPopup))
+            mVisibleHash.insert(it.key(), it.value());
+    }*/
+}
+
 /************************************************
 
  ************************************************/
 int UKUITaskGroup::visibleButtonsCount() const
 {
     int i = 0;
+#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
+    for (auto it=mButtonHash.begin();it!=mButtonHash.end();it++)
+     {
+        UKUITaskWidget *btn=it.value();
+        if (btn->isVisibleTo(mPopup))
+            i++;
+    }
+#else
     for (UKUITaskWidget *btn : qAsConst(mButtonHash))
         if (btn->isVisibleTo(mPopup))
             i++;
+#endif
     return i;
 }
 
@@ -423,11 +465,10 @@ void UKUITaskGroup::draggingTimerTimeout()
  ************************************************/
 void UKUITaskGroup::onClicked(bool)
 {
-//    if (visibleButtonsCount() > 1)
-//    {
-//        setChecked(mButtonHash.contains(KWindowSystem::activeWindow()));
-//        setPopupVisible(true);
-//    }
+    if (1 == mVisibleHash.size())
+    {
+        return singleWindowClick();
+    }
     if(mPopup->isVisible())
     {
         if(HOVER == taskgroupStatus)
@@ -453,6 +494,35 @@ void UKUITaskGroup::onClicked(bool)
 }
 
 
+void UKUITaskGroup::singleWindowClick()
+{
+    UKUITaskWidget *btn = mButtonHash.begin().value();
+    if(btn)
+    {
+        if(!btn->isFocusState())
+        {
+            if(mPopup->isVisible())
+            {
+                mPopup->hide();
+            }
+            KWindowSystem::activateWindow(mButtonHash.begin().key());
+        }
+        else
+        {
+            btn->minimizeApplication();
+            if(mPopup->isVisible())
+            {
+                mPopup->hide();
+            }
+        }
+    }
+    mTaskGroupEvent = OTHEREVENT;
+    if(mTimer->isActive())
+    {
+       mTimer->stop();
+    }
+}
+
 /************************************************
 
  ************************************************/
@@ -527,12 +597,16 @@ void UKUITaskGroup::refreshVisibility()
     bool will = false;
     UKUITaskBar const * taskbar = parentTaskBar();
     const int showDesktop = taskbar->showDesktopNum();
-    for(UKUITaskWidget * btn : qAsConst(mButtonHash))
+
+    for(UKUITaskButtonHash::const_iterator i=mButtonHash.begin();i!=mButtonHash.end();i++)
     {
+        UKUITaskWidget * btn=i.value();
         bool visible = taskbar->isShowOnlyOneDesktopTasks() ? btn->isOnDesktop(0 == showDesktop ? KWindowSystem::currentDesktop() : showDesktop) : true;
         visible &= taskbar->isShowOnlyCurrentScreenTasks() ? btn->isOnCurrentScreen() : true;
         visible &= taskbar->isShowOnlyMinimizedTasks() ? btn->isMinimized() : true;
         btn->setVisible(visible);
+        if (btn->isVisibleTo(mPopup) && !mVisibleHash.contains(i.key()))
+            mVisibleHash.insert(i.key(), i.value());
         will |= visible;
     }
 
@@ -832,25 +906,77 @@ void UKUITaskGroup::groupPopupShown(UKUITaskGroup * const sender)
 
 void UKUITaskGroup::removeWidget()
 {
-    mPopup->layout()->removeWidget(mpWidget);
-    QHBoxLayout *hLayout = dynamic_cast<QHBoxLayout*>(mpWidget->layout());
-    QVBoxLayout *vLayout = dynamic_cast<QVBoxLayout*>(mpWidget->layout());
-    if(hLayout != NULL)
+    if(mpScrollArea)
     {
-        hLayout->deleteLater();
-        hLayout = NULL;
+        removeSrollWidget();
     }
-    if(vLayout != NULL)
+    if(mpWidget)
     {
-        vLayout->deleteLater();
-        vLayout = NULL;
+        mPopup->layout()->removeWidget(mpWidget);
+        QHBoxLayout *hLayout = dynamic_cast<QHBoxLayout*>(mpWidget->layout());
+        QVBoxLayout *vLayout = dynamic_cast<QVBoxLayout*>(mpWidget->layout());
+        if(hLayout != NULL)
+        {
+            hLayout->deleteLater();
+            hLayout = NULL;
+        }
+        if(vLayout != NULL)
+        {
+            vLayout->deleteLater();
+            vLayout = NULL;
+        }
+        //mpWidget->setParent(NULL);
+        mpWidget->deleteLater();
+        mpWidget = NULL;
     }
-    mpWidget->deleteLater();
-    mpWidget = NULL;
+}
+
+
+void UKUITaskGroup::removeSrollWidget()
+{
+    if(mpScrollArea)
+    {
+        mPopup->layout()->removeWidget(mpScrollArea);
+        mPopup->layout()->removeWidget(mpScrollArea->takeWidget());
+    }
+    if(mpWidget)
+    {
+        mPopup->layout()->removeWidget(mpWidget);
+        QHBoxLayout *hLayout = dynamic_cast<QHBoxLayout*>(mpWidget->layout());
+        QVBoxLayout *vLayout = dynamic_cast<QVBoxLayout*>(mpWidget->layout());
+        if(hLayout != NULL)
+        {
+            hLayout->deleteLater();
+            hLayout = NULL;
+        }
+        if(vLayout != NULL)
+        {
+            vLayout->deleteLater();
+            vLayout = NULL;
+        }
+        //mpWidget->setParent(NULL);
+        mpWidget->deleteLater();
+        mpWidget = NULL;
+    }
+    if(mpScrollArea)
+    {
+        mpScrollArea->deleteLater();
+        mpScrollArea = NULL;
+    }
+
 }
 
 void UKUITaskGroup::setLayOutForPostion()
 {
+    if(mVisibleHash.size() > 10)//more than 10 need
+    {
+        mpWidget->setLayout(new QVBoxLayout);
+        mpWidget->layout()->setAlignment(Qt::AlignTop);
+        mpWidget->layout()->setSpacing(3);
+        mpWidget->layout()->setMargin(3);
+        return;
+    }
+
     if(plugin()->panel()->isHorizontal())
     {
         mpWidget->setLayout(new QHBoxLayout);
@@ -880,13 +1006,185 @@ bool UKUITaskGroup::isSetMaxWindow()
 }
 
 void UKUITaskGroup::showPreview()
+{
+    if(mVisibleHash.size()<=10)
+    {
+        showAllWindowByThumbnail();
+    }
+    else
+    {
+        showAllWindowByList();
+    }
+}
+
+void UKUITaskGroup::adjustPopWindowSize(int winWidth, int winHeight)
+{
+    int size = mVisibleHash.size();
+    if(plugin()->panel()->isHorizontal())
+    {
+        mPopup->setFixedSize(winWidth*size + (size + 1)*3, winHeight + 6);
+    }
+    else
+    {
+        mPopup->setFixedSize(winWidth + 6,winHeight*size + (size + 1)*3);
+    }
+    mPopup->adjustSize();
+}
+
+void UKUITaskGroup::v_adjustPopWindowSize(int winWidth, int winHeight, int v_all)
+{
+    int fixed_size = v_all;
+    int iScreenWidth = QApplication::screens().at(0)->size().width();
+
+    if (fixed_size > iScreenWidth)
+        fixed_size = iScreenWidth;
+
+    if(plugin()->panel()->isHorizontal())
+    {
+        mPopup->setFixedSize(fixed_size,  winHeight + 6);
+    }
+    else
+    {
+        mPopup->setFixedSize(winWidth + 6, fixed_size);
+    }
+    mPopup->adjustSize();
+}
+
+void UKUITaskGroup::timeout()
+{
+
+    if(mTaskGroupEvent == ENTEREVENT)
+    {
+        if(mTimer->isActive())
+        {
+            mTimer->stop();
+        }
+        handleSavedEvent();
+    }
+    else if(mTaskGroupEvent == LEAVEEVENT)
+    {
+        if(mTimer->isActive())
+        {
+            mTimer->stop();
+        }
+        setPopupVisible(false);
+        QToolButton::leaveEvent(mEvent);
+        taskgroupStatus = NORMAL;
+        update();
+    }
+    else
+    {
+        setPopupVisible(false);
+    }
+}
+
+int UKUITaskGroup::calcAverageHeight()
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        return 0;
+    }
+    else
+    {
+        int size = mVisibleHash.size();
+        int iScreenHeight = QApplication::screens().at(0)->size().height();
+        int iMarginHeight = (size+1)*3;
+        int iAverageHeight = (iScreenHeight - iMarginHeight)/size;//calculate average width of window
+        return iAverageHeight;
+    }
+}
+
+int UKUITaskGroup::calcAverageWidth()
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        int size = mVisibleHash.size();
+        int iScreenWidth = QApplication::screens().at(0)->size().width();
+        int iMarginWidth = (size+1)*3;
+        int iAverageWidth = (iScreenWidth - iMarginWidth)/size;//calculate average width of window
+        return iAverageWidth;
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+
+void UKUITaskGroup::showAllWindowByList()
+{
+    int winWidth = 246;
+    int winheight = 46;
+    int iPreviewPosition = 0;
+    int popWindowheight =( winheight - 2) * mVisibleHash.size() + 3;
+    int screenAvailabelHeight = QApplication::screens().at(0)->size().height() - plugin()->panel()->panelSize();
+    if(!plugin()->panel()->isHorizontal())
+    {
+        screenAvailabelHeight = QApplication::screens().at(0)->size().height();//panel is vect
+    }
+    if(mPopup->layout()->count() > 0)
+    {
+        removeSrollWidget();
+    }
+    mpScrollArea = new QScrollArea();
+    mpScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    mpScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+
+    mpScrollArea->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    mpScrollArea->setWidgetResizable(true);
+    mpScrollArea->setFixedWidth(winWidth-10);
+    mpScrollArea->setFrameStyle(QFrame::NoFrame);
+
+    mPopup->layout()->addWidget(mpScrollArea);
+    mpWidget = new QWidget();
+    mpWidget->setFixedWidth(mpScrollArea->width());
+    mpScrollArea->setWidget(mpWidget);
+    //mpWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+//    mpWidget->setAttribute(Qt::WA_TranslucentBackground);
+    setLayOutForPostion();
+    /*begin catch preview picture*/
+    for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    {
+        UKUITaskWidget *btn = it.value();
+        btn->removeThumbNail();
+        btn->updateTitle();
+        btn->setTitleFixedWidth(winWidth - 80);
+//        btn->setFixedSize(mpScrollArea->width(),winheight);
+        btn->adjustSize();
+        mpWidget->layout()->setContentsMargins(0,0,0,0);
+        mpWidget->layout()->addWidget(btn);
+    }
+    /*end*/
+    plugin()->willShowWindow(mPopup);
+    mPopup->setFixedSize(winWidth,  popWindowheight < screenAvailabelHeight? popWindowheight : screenAvailabelHeight);
+    mPopup->adjustSize();
+    if(plugin()->panel()->isHorizontal())
+    {
+        iPreviewPosition =  plugin()->panel()->panelSize()/2 - winWidth/2;
+        mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(iPreviewPosition,0)), mPopup->size()));
+    }
+    else
+    {
+        iPreviewPosition = plugin()->panel()->panelSize()/2 - winWidth/2;
+        mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(0,iPreviewPosition)), mPopup->size()));
+    }
+    mPopup->show();
+
+   emit popupShown(this);
+}
+
+
+void UKUITaskGroup::showAllWindowByThumbnail()
 {
     XImage *img = NULL;
     Display *display = NULL;
     QPixmap thumbnail;
     XWindowAttributes attr;
+    int previewPosition = 0;
     int winWidth = 0;
     int winHeight = 0;
+   // initVisibleHash();
+    refreshVisibility();
     int iAverageWidth = calcAverageWidth();
     int iAverageHeight = calcAverageHeight();
     /*begin get the winsize*/
@@ -928,32 +1226,103 @@ void UKUITaskGroup::showPreview()
     mpWidget->setAttribute(Qt::WA_TranslucentBackground);
     setLayOutForPostion();
     /*begin catch preview picture*/
+
+    int max_Height = 0;
+    int max_Width = 0;
+    int imgWidth_sum = 0;
+    int changed = 0;
+    int title_width = 0;
+    int v_all = 0;
+    int iScreenWidth = QApplication::screens().at(0)->size().width();
+    float minimumWidth = THUMBNAIL_WIDTH;
+    float minimumHeight = THUMBNAIL_HEIGHT;
+    for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    {
+        display = XOpenDisplay(nullptr);
+        XGetWindowAttributes(display, it.key(), &attr);
+        max_Height = attr.height > max_Height ? attr.height : max_Height;
+        max_Width = attr.width > max_Width ? attr.width : max_Width;
+        if(display)
+            XCloseDisplay(display);
+    }
     for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
     {
         UKUITaskWidget *btn = it.value();
+        btn->addThumbNail();
         display = XOpenDisplay(nullptr);
         XGetWindowAttributes(display, it.key(), &attr);
         img = XGetImage(display, it.key(), 0, 0, attr.width, attr.height, 0xffffffff,ZPixmap);
+        float imgWidth = 0;
+        float imgHeight = 0;
+        if (plugin()->panel()->isHorizontal()) {
+            imgWidth = (float)attr.width / (float)attr.height * THUMBNAIL_HEIGHT;
+            imgHeight = THUMBNAIL_HEIGHT;
+        } else {
+            imgWidth = THUMBNAIL_WIDTH;
+            imgHeight = (float)attr.height / (float)attr.width * THUMBNAIL_WIDTH;
+        }
+        if (plugin()->panel()->isHorizontal())
+        {
+            if (attr.height != max_Height)
+            {
+                float tmp = (float)attr.height / (float)max_Height;
+                imgHeight =  imgHeight * tmp;
+            }
+            if ((int)imgWidth > (int)minimumWidth)
+            {
+                imgWidth = minimumWidth;
+            }
+            if (btn->isVisibleTo(mPopup)) {
+                v_all += (int)imgWidth;
+                imgWidth_sum += (int)imgWidth;
+            }
+            if (mVisibleHash.size() == 1 ) changed = (int)imgWidth;
+            btn->setThumbMaximumSize(MAX_SIZE_OF_Thumb);
+            btn->setThumbScale(true);
+        } else {
+            if (attr.width != max_Width)
+            {
+                float tmp = (float)attr.width / (float)max_Width;
+                imgWidth =  imgWidth * tmp;
+            }
+            if ((int)imgHeight > (int)minimumHeight)
+            {
+                imgHeight = minimumHeight;
+            }
+            if (btn->isVisibleTo(mPopup)) {
+                v_all += (int)imgHeight;
+            }
+            if (mVisibleHash.size() == 1 ) changed = (int)imgHeight;
+            if ((int)imgWidth < 150)
+            {
+                btn->setThumbFixedSize((int)imgWidth);
+                btn->setThumbScale(false);
+            } else {
+                btn->setThumbMaximumSize(MAX_SIZE_OF_Thumb);
+                btn->setThumbScale(true);
+            }
+        }
         if(img)
         {
-            thumbnail = qimageFromXImage(img).scaled(THUMBNAIL_WIDTH,THUMBNAIL_HEIGHT,Qt::KeepAspectRatio,Qt::SmoothTransformation);
-            //thumbnail.save(QString("/tmp/picture/%1.png").arg(it.key()));  test picture if correct
-            btn->setThumbNail(thumbnail);
+            thumbnail = qimageFromXImage(img).scaled((int)imgWidth, (int)imgHeight, Qt::KeepAspectRatio,Qt::SmoothTransformation);
+            if (!parentTaskBar()->getCpuInfoFlg()) thumbnail.save(QString("/tmp/%1.png").arg(it.key()));
         }
         else
         {
-            QPixmap emptyThumbnail;
-            btn->setThumbNail(emptyThumbnail);
             qDebug()<<"can not catch picture";
+            QPixmap pxmp;
+            if (pxmp.load(QString("/tmp/%1.png").arg(it.key())))
+                thumbnail = pxmp.scaled((int)imgWidth, (int)imgHeight, Qt::KeepAspectRatio,Qt::SmoothTransformation);
+            else {
+                thumbnail = QPixmap((int)imgWidth, (int)imgHeight);
+                thumbnail.fill(QColor(0, 0, 0, 127));
+            }
         }
-
-//        UKUITaskWidget *btn = it.value();
-//        btn->setThumbNail(thumbnail);
+        btn->setThumbNail(thumbnail);
         btn->updateTitle();
-        btn->setFixedSize(winWidth, winHeight);
+        btn->setFixedSize((int)imgWidth, (int)imgHeight);
         mpWidget->layout()->setContentsMargins(0,0,0,0);
         mpWidget->layout()->addWidget(btn);
-
         if(img)
         {
            XDestroyImage(img);
@@ -964,94 +1333,65 @@ void UKUITaskGroup::showPreview()
         }
     }
     /*end*/
+    int i = 0;
+        for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+        {
+            UKUITaskWidget *btn = it.value();
+            if (plugin()->panel()->isHorizontal())  {
+                if (imgWidth_sum > iScreenWidth)
+                    title_width = (int)(btn->width()  * iScreenWidth / imgWidth_sum - 80);
+                else
+                    title_width = btn->width() - 75;
+            } else {
+                 title_width = winWidth- 70;
+            }
+            btn->setTitleFixedWidth(title_width);
+        }
     plugin()->willShowWindow(mPopup);
     mPopup->layout()->addWidget(mpWidget);
-    adjustPopWindowSize(winWidth, winHeight);
-    mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(0,0)), mPopup->size()));
-    mPopup->show();
+    if (mVisibleHash.size() == 1 && changed != 0)
+        if (plugin()->panel()->isHorizontal()) {
+            adjustPopWindowSize(changed, winHeight);
+        } else {
+            adjustPopWindowSize(winWidth, changed);
+        }
+    else if (mVisibleHash.size() != 1)
+        v_adjustPopWindowSize(winWidth, winHeight, v_all);
+    else
+        adjustPopWindowSize(winWidth, winHeight);
+
+    if(plugin()->panel()->isHorizontal())//set preview window position
+    {
+        if(mPopup->size().width()/2 < QCursor::pos().x())
+        {
+            previewPosition = 0 - mPopup->size().width()/2 + plugin()->panel()->panelSize()/2;
+        }
+        else
+        {
+            previewPosition = 0 -(QCursor::pos().x() + plugin()->panel()->panelSize()/2);
+        }
+        mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(previewPosition,0)), mPopup->size()));
+    }
+    else
+    {
+        if(mPopup->size().height()/2 < QCursor::pos().y())
+        {
+            previewPosition = 0 - mPopup->size().height()/2 + plugin()->panel()->panelSize()/2;
+        }
+        else
+        {
+            previewPosition = 0 -(QCursor::pos().y() + plugin()->panel()->panelSize()/2);
+        }
+        mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(0,previewPosition)), mPopup->size()));
+    }
+    if(mPopup->isVisible())
+    {
+//        mPopup-
+    }
+    else
+    {
+        mPopup->show();
+    }
 
    emit popupShown(this);
 }
-
-void UKUITaskGroup::adjustPopWindowSize(int winWidth, int winHeight)
-{
-    if(plugin()->panel()->isHorizontal())
-    {
-        mPopup->setFixedSize(winWidth*mButtonHash.size() + (mButtonHash.size() + 1)*3, winHeight + 6);
-    }
-    else
-    {
-        mPopup->setFixedSize(winWidth + 6,winHeight*mButtonHash.size() + (mButtonHash.size() + 1)*3);
-    }
-    mPopup->adjustSize();
-}
-
-void UKUITaskGroup::timeout()
-{
-
-    if(mTaskGroupEvent == ENTEREVENT)
-    {
-        if(mTimer->isActive())
-        {
-            mTimer->stop();
-        }
-        handleSavedEvent();
-    }
-    else if(mTaskGroupEvent == LEAVEEVENT)
-    {
-        if(mTimer->isActive())
-        {
-            mTimer->stop();
-        }
-        setPopupVisible(false);
-        QToolButton::leaveEvent(mEvent);
-        taskgroupStatus = NORMAL;
-        update();
-    }
-    else
-    {
-        setPopupVisible(false);
-    }
-}
-
-int UKUITaskGroup::calcAverageHeight()
-{
-    if(plugin()->panel()->isHorizontal())
-    {
-        return 0;
-    }
-    else
-    {
-        int iScreenHeight = QApplication::screens().at(0)->size().height();
-        int iMarginHeight = (mButtonHash.size()+1)*3;
-        int iAverageHeight = (iScreenHeight - iMarginHeight)/mButtonHash.size();//calculate average width of window
-        return iAverageHeight;
-    }
-}
-
-int UKUITaskGroup::calcAverageWidth()
-{
-    if(plugin()->panel()->isHorizontal())
-    {
-        int iScreenWidth = QApplication::screens().at(0)->size().width();
-        int iMarginWidth = (mButtonHash.size()+1)*3;
-        int iAverageWidth = (iScreenWidth - iMarginWidth)/mButtonHash.size();//calculate average width of window
-        return iAverageWidth;
-    }
-    else
-    {
-        return 0;
-    }
-}
-
-
-void UKUITaskGroup::showAllWindowByList()
-{
-
-}
-
-
-void UKUITaskGroup::showAllWindowByThumbnail()
-{
-
-}
