@@ -38,6 +38,12 @@
 #include "ukuitaskbutton.h"
 #include <KF5/KWindowSystem/kwindowsystem.h>
 #include <QTimer>
+#include <QScrollArea>
+#include "../panel/ukuipanelpluginconfigdialog.h"
+#include "../panel/pluginsettings.h"
+#include <QAbstractButton>
+//#include <Xlib.h>
+
 
 class QVBoxLayout;
 class IUKUIPanelPlugin;
@@ -56,6 +62,7 @@ public:
 
     int buttonsCount() const;
     int visibleButtonsCount() const;
+    void initVisibleHash();
 
     QWidget * addWindow(WId id);
     QWidget * checkedButton() const;
@@ -72,13 +79,15 @@ public:
     void setPopupVisible(bool visible = true, bool fast = false);
 
     void removeWidget();
+    void removeSrollWidget();
     bool isSetMaxWindow();
     void showPreview();
     int calcAverageWidth();
     int calcAverageHeight();
     void showAllWindowByList();//when number of window is more than 30,need show all window of app by a list
     void showAllWindowByThumbnail();//when number of window is no more than 30,need show all window of app by a thumbnail
-
+    void singleWindowClick();
+    void VisibleWndRemoved(WId window);
 public slots:
     void onWindowRemoved(WId window);
     void timeout();
@@ -117,10 +126,12 @@ signals:
     void popupShown(UKUITaskGroup* sender);
 
 private:
+    void changeTaskButtonStyle();
     QString mGroupName;
     UKUIGroupPopup * mPopup;
     QVBoxLayout *VLayout;
     UKUITaskButtonHash mButtonHash;
+    UKUITaskButtonHash mVisibleHash;
     bool mPreventPopup;
     bool mSingleButton; //!< flag if this group should act as a "standard" button (no groupping or only one "shown" window in group)
     enum TaskGroupStatus{NORMAL, HOVER, PRESS};
@@ -128,12 +139,14 @@ private:
     TaskGroupStatus taskgroupStatus;
     TaskGroupEvent  mTaskGroupEvent;
     QWidget *mpWidget;
+    QScrollArea *mpScrollArea;
     QEvent * mEvent;
     QTimer *mTimer;
     QSize recalculateFrameSize();
     QPoint recalculateFramePosition();
     void recalculateFrameIfVisible();
     void adjustPopWindowSize(int width, int height);
+    void v_adjustPopWindowSize(int width, int height, int v_all);
     void regroup();
 
 };
