@@ -1,10 +1,6 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * Copyright: 2019 Kylin team
- * Authors:
- *   hepuyao <hepuyao@kylinos.cn>
- *
  * Copyright: 2019 Tianjin KYLIN Information Technology Co., Ltd. *
  *
  * This program or library is free software; you can redistribute it
@@ -28,78 +24,65 @@
 #define UKUITRAY_H
 
 #include <QFrame>
+#include <QWidget>
 #include <QAbstractNativeEventFilter>
-#include "../panel/iukuipanel.h"
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <xcb/xcb_event.h>
 #include "fixx11h.h"
 #include <QScreen>
-#include "traystorage.h"
-#include "../panel/customstyle.h"
-#include "../panel/ukuicontrolstyle.h"
 #include <QGSettings>
 #include <string.h>
 #include <string>
+#include <QToolButton>
+#include <QMap>
+
+#include "../panel/iukuipanel.h"
+#include "../panel/customstyle.h"
+#include "../panel/ukuicontrolstyle.h"
+#include "ukuitraystrage.h"
+
 class TrayIcon;
 class QSize;
 namespace UKUi {
 class GridLayout;
 }
 
-enum storageBarStatus{ST_HIDE,ST_SHOW};
 /**
  * @brief This makes our trayplugin
  */
-class IUKUIPanelPlugin;
-
-class UKUIStorageFrame:public QWidget
-{
-    Q_OBJECT
-public:
-    UKUIStorageFrame(QWidget* parent =0);
-    ~UKUIStorageFrame();
-protected:
-//    bool event(QEvent *e);
-    bool eventFilter(QObject *watched, QEvent *event);
-    bool nativeEvent(const QByteArray &eventType, void *message, long *result);
-    void paintEvent(QPaintEvent *event);
-private:
-    Atom _NET_SYSTEM_TRAY_OPCODE;
-    UKUi::GridLayout *storageLayout;
-};
+class UKUITrayPlugin;
 
 class UKUITray: public QFrame, QAbstractNativeEventFilter
 {
     Q_OBJECT
-    Q_PROPERTY(QSize iconSize READ iconSize WRITE setIconSize)
+//    Q_PROPERTY(QSize iconSize READ iconSize WRITE setIconSize)
 public:
-    UKUITray(IUKUIPanelPlugin *plugin, QWidget* parent = 0);
+    UKUITray(UKUITrayPlugin *plugin, QWidget* parent = 0);
     ~UKUITray();
 
     QSize iconSize() const { return mIconSize; }
-    void setIconSize(QSize iconSize);
-
+    void setIconSize();
     bool nativeEventFilter(const QByteArray &eventType, void *message, long *);
-
-    void realign();
-    IUKUIPanelPlugin *mPlugin;
-//    TrayStorage *tys;
+    UKUITrayPlugin *mPlugin;
 
     //control app show in tray/traystorege  by ukui-control-center
     QList<char *> listExistsPath();
     QString findFreePath();
-
     void regulateIcon(Window *mid);
+    void newAppDetect(int wid);
     void freezeApp();
+    void showAndHideStorage(bool);
 
 public slots:
     void storageBar();
-    void storageAddIcon(Window winId);
+    void changeIcon();
+    void realign();
 
 signals:
     void iconSizeChanged(int iconSize);
     void freezeIcon(TrayIcon *icon,Window winid);
+    void positionChanged();
 
 private slots:
     void startTray();
@@ -107,6 +90,8 @@ private slots:
     void stopStorageTray();
     void onIconDestroyed(QObject * icon);
     void freezeTrayApp(Window winId);
+    void trayIconSizeRefresh();
+
 private:
     VisualID getVisual();
     void clientMessageEvent(xcb_generic_event_t *e);
@@ -116,25 +101,42 @@ private:
                       long unsigned int data2 = 0,
                       long unsigned int data3 = 0,
                       long unsigned int data4 = 0) const;
-    void addIcon(Window id);
+
+    /*
+     * @brief Dynamic mobile tray application
+     */
+    void addTrayIcon(Window id);
+    void addStorageIcon(Window winId);
+    void addHideIcon(Window winId);
     void moveIconToStorage(Window id);
     void moveIconToTray(Window winId);
+    void moveIconToHide(Window winId);
+    void handleStorageUi();
     TrayIcon* findIcon(Window trayId);
+    TrayIcon* findTrayIcon(Window trayId);
     TrayIcon* findStorageIcon(Window trayId);
+    TrayIcon* findHideIcon(Window trayId);
+    void createIconMap();
 
     bool mValid;
     Window mTrayId;
     QList<TrayIcon*> mIcons;
+    QList<TrayIcon*> mTrayIcons;
     QList<TrayIcon*> mStorageIcons;
+    QList<TrayIcon*> mHideIcons;
     int mDamageEvent;
     int mDamageError;
     QSize mIconSize;
-    UKUi::GridLayout *mLayout;
-    UKUi::GridLayout *storageLayout;
-    QToolButton *bt;
 
     Atom _NET_SYSTEM_TRAY_OPCODE;
     Display* mDisplay;
     UKUIStorageFrame *storageFrame;
+    UKUiStorageWidget *m_pwidget;
+    QToolButton *mBtn;
+    IUKUIPanel::Position mCurPosition;
+    QMap<IUKUIPanel::Position, QIcon> mMapIcon;
+    QPixmap drawSymbolicColoredPixmap(const QPixmap &source);
+    QGSettings *settings;
 };
+
 #endif
