@@ -18,7 +18,12 @@
 #ifndef UNIONVARIABLE_H
 #define UNIONVARIABLE_H
 #include <QList>
-#include <PeonyVolumeManager>
-QList<std::shared_ptr<Peony::Mount>> *findList();
-QList<std::shared_ptr<Peony::Volume>> *findVolumeList();
+#include <gio/gio.h>
+#include <QString>
+#include <QFont>
+#include <QFontMetrics>
+QList<GMount *> *findGMountList();
+QList<GVolume *> *findGVolumeList();
+QList<GDrive *> *findGDriveList();
+QString getElidedText(QFont font, QString str, int MaxWidth);
 #endif
